package com.xx.hbhconsumer.dialog.adapter;

import android.content.Context;
import android.util.Log;
import android.view.View;
import android.widget.Toast;

import com.google.gson.Gson;
import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.data.http.respons.MessageBean;
import com.xx.hbhconsumer.data.http.respons.ParkBean;
import com.xx.hbhconsumer.data.staticdata.StaticData;
import com.xx.hbhconsumer.databinding.ItemParkBinding;
import com.xx.xxviewlibrary.base.xxBaseRecyclerViewAdapter;

public class ParkAdapter extends xxBaseRecyclerViewAdapter<ItemParkBinding, ParkBean> {

    public ParkAdapter(Context context) {
        super(context);
    }

    // 定义长按事件的回调接口
    public interface OnItemLongClickListener {
        void onItemLongClick(View view, int position, ParkBean parkBean);
    }

    // 定义一个成员变量，用于存储回调接口的实例
    private OnItemLongClickListener onItemLongClickListener;

    // 提供一个方法，用于设置回调接口的实例
    public void setOnItemLongClickListener(OnItemLongClickListener listener) {
        this.onItemLongClickListener = listener;
    }

    @Override
    public int initLayout() {
        return R.layout.item_park;
    }


    @Override
    protected void covert(ItemParkBinding dataBind, ParkBean data, int position) {
        //   将接口调出来的布局遍历上去
        dataBind.setParkBean(data);
        Gson gson = new Gson();

        dataBind.itemLayout.setOnLongClickListener(new View.OnLongClickListener() {
            @Override
            public boolean onLongClick(View v) {
                if (onItemLongClickListener != null) {
                    // 如果有设置回调接口，则调用回调方法
                    onItemLongClickListener.onItemLongClick(v, position, data);
                }
                // 处理长按事件
//                Toast.makeText(v.getContext(), "长按事件触发，位置：" + position + "，车牌号：" + data.getPlateNumber(), Toast.LENGTH_SHORT).show();
                // 返回 true 表示已处理长按事件
                return true;
            }
        });
        String type = data.getType(); // 先获取类型
        if (type != null && !type.isEmpty()) {
            // 先检查是否为 null，再检查是否为空字符串
            Log.v("消息列表的重要信息:", type);
            /*根据车辆类型判断显示图标 1-普通油车,2-新能源车*/
            if (data.getType().equals("1") && !data.getType().isEmpty()) {
                /*普通油车*/
                dataBind.ivTopLeftEleic.setVisibility(View.GONE);
                dataBind.ivTopLeftOil.setVisibility(View.VISIBLE);
            } else if (data.getType().equals("2") && !data.getType().isEmpty()) {
                /*新能源*/
                dataBind.ivTopLeftEleic.setVisibility(View.VISIBLE);
                dataBind.ivTopLeftOil.setVisibility(View.GONE);
            }
        }
        // 获取车牌号并格式化
        String plateNumber = data.getPlateNumber();
        if (plateNumber != null && plateNumber.length() >= 2) {
            // 取前两位和后面的字符，中间用点连接
            String formattedPlateNumber = plateNumber.substring(0, 2) + "·" + plateNumber.substring(2);
            // 设置到绑定的视图中（假设有一个TextView用于显示车牌号）
            dataBind.tvParkNumber.setText(formattedPlateNumber);
        }
        // 获取停车时长并格式化
        String parkingTime = data.getParkingTime();
        if (parkingTime != null && !parkingTime.isEmpty()) {
            long milliseconds = Long.parseLong(parkingTime); // 将字符串转换为毫秒值
            long seconds = milliseconds / 1000; // 转换为秒
            long hours = seconds / 3600; // 计算小时数
            seconds = seconds % 3600; // 剩余的秒数
            long minutes = seconds / 60; // 计算分钟数
            seconds = seconds % 60; // 剩余的秒数
            dataBind.tvParkParkingTime.setText("已停车" + hours + "小时" + minutes + "分" + seconds + "秒");
        } else {
            dataBind.tvParkParkingTime.setText("暂无停车信息");
        }
        // 获取应付金额并格式化
        String payCharge = data.getPayCharge();
        if (payCharge != null && !payCharge.isEmpty()) {
            dataBind.tvParkPayChargeLayout.setVisibility(View.VISIBLE);
        } else {
            dataBind.tvParkPayChargeLayout.setVisibility(View.GONE);
        }
    }

}


