package com.xx.hbhconsumer.ui.activity;

import android.app.Application;
import android.os.Bundle;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.ActivityRequest;
import com.xx.hbhconsumer.data.http.requst.MineRequest;
import com.xx.hbhconsumer.data.http.respons.ActivityCenterBean;
import com.xx.hbhconsumer.data.http.respons.ActivityCouponBean;
import com.xx.hbhconsumer.data.http.respons.CategoryBean;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.ui.category.CategoryViewModel;
import com.xx.hbhconsumer.ui.coupon.CouponListActivity;
import com.xx.hbhconsumer.ui.pwd.PwdActivity;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class ActivityViewModel extends BaseViewModel<ActivityRequest> {
    public int page = 1;
    public int totalPage = 1;
    public MutableLiveData<List<ActivityCouponBean>> couponList = new  MutableLiveData<>(new ArrayList<>());
    public MutableLiveData<List<ActivityCenterBean>> activityList = new  MutableLiveData<>(new ArrayList<>());

    public ActivityViewModel(@NonNull Application application) {
        super(application);
    }

    public ActivityViewModel(@NonNull Application application, ActivityRequest model) {
        super(application, model);
    }

    //跳转修改手机号界面
    public BindingCommand goCouponList = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(CouponListActivity.class);
        }

    });

    public void goActivityDetail(String activityUrl) {
        Bundle bundle = new Bundle();
        bundle.putString("activityUrl", activityUrl);
        startActivity(ActivityDetailActivity.class, bundle);
    }

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        loadData();
        getActivityCenterList();
    }

    public void getCoupon(String couponId) {
        model.getCoupon(couponId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(ActivityViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<Integer>() {
                    @Override
                    public void onSuccess(Integer resultBean) {
                        ToastUtils.showShort("领取成功");
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

    private void loadData() {
        model.getCouponAppList(page)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(ActivityViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
//                            throw new Exception("发生了一个错误");
                    }
                }).subscribe(new ApiDisposablePageObserver<ActivityCouponBean>() {
                    @Override
                    public void onSuccess(List<ActivityCouponBean> resultBean) {
                        
                        List<ActivityCouponBean> list = new ArrayList<>();
                        for (ActivityCouponBean activityCouponBean : resultBean) {
                            if ("1".equals(activityCouponBean.getCouponType())) {
                                list.add(activityCouponBean);
                            }
                        }
                        if (list.size() <= 5) {
                            couponList.postValue(list);
                        } else {
                            couponList.postValue(list.subList(0, 5));
                        }

                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {
                    }


                });
    }

    //调用活动中心的接口信息
    public void getActivityCenterList() {
        model.getActivityList(page)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(ActivityViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<ActivityCenterBean>() {
                    @Override
                    public void onSuccess(List<ActivityCenterBean> resultBean) {
                        if (page == 1) {
                            activityList.postValue(resultBean);
                        } else {
                            List<ActivityCenterBean> list = activityList.getValue();
                            list.addAll(resultBean);
                            activityList.postValue(list);
                        }

                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {
                        totalPage = (total - 1) / 10 + 1;
                    }
                });
    }
}