package com.xx.hbhconsumer.ui.category;

import android.app.Application;
import android.content.Intent;
import android.os.Bundle;

import androidx.annotation.NonNull;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.CategoryRequest;
import com.xx.hbhconsumer.data.http.respons.CategoryBean;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.ui.goods.GoodsListActivity;
import com.xx.hbhconsumer.ui.order.OrderDetailActivity;
import com.xx.hbhconsumer.ui.shop.ShopSearchActivity;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.StringUtils;

public class CategoryViewModel extends BaseViewModel<CategoryRequest> {

    String merchantId;

    public MutableLiveData<List<CategoryBean>> categoryBeanList = new  MutableLiveData<>(new ArrayList<>());
    public MutableLiveData<List<CategoryBean>> secondBeanList = new  MutableLiveData<>(new ArrayList<>());

    public CategoryViewModel(@NonNull Application application) {
        super(application);
    }

    public CategoryViewModel(@NonNull Application application, CategoryRequest model, String merchantId) {
        super(application, model);
        this.merchantId = merchantId;
    }

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        String affiliatedCompany = LocalData.getAffiliatedCompany();
        loadData(affiliatedCompany);
    }

    private void loadData(String affiliatedCompany) {
        model.getCategoryTree(affiliatedCompany)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(CategoryViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<List<CategoryBean>>() {
                    @Override
                    public void onSuccess(List<CategoryBean> resultBean) {
                        if (resultBean.size() > 0) {
                            resultBean.get(0).setChecked(true);
                            secondBeanList.postValue(resultBean.get(0).getChildren());
                        }
                        categoryBeanList.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }


                });
    }

    public void changeSecondCategoryList(int position) {
        secondBeanList.postValue(categoryBeanList.getValue().get(position).getChildren());

        for (int i = 0; i < categoryBeanList.getValue().size(); i++) {
            if (i == position) {
                categoryBeanList.getValue().get(i).setChecked(true);
            } else {
                categoryBeanList.getValue().get(i).setChecked(false);
            }
        }
    }

    public void goGoodsList(String categoryId) {
        if (StringUtils.isEmpty(merchantId)) {
            Bundle bundle = new Bundle();
            bundle.putString("categoryId", categoryId);
            startActivity(GoodsListActivity.class, bundle);
        } else {
            Bundle bundle = new Bundle();
            bundle.putString("categoryId", categoryId);
            bundle.putString("merchantId", merchantId);
            startActivity(ShopSearchActivity.class, bundle);
        }

    }
}
