package com.xx.hbhconsumer.ui.credit;

import android.app.Application;

import androidx.annotation.NonNull;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.CreditRequest;
import com.xx.hbhconsumer.data.http.respons.CreditDetailBean;
import com.xx.hbhconsumer.data.http.respons.CreditRecordBean;
import com.xx.hbhconsumer.data.http.respons.YearBean;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;

public class CreditDetailViewModel extends BaseViewModel<CreditRequest> {

    public int page = 1;
    public int totalPage = 1;
    public int selectYear = 0;
    public String incomeType = "1";
    public MutableLiveData<Boolean> checkYearFlag = new MutableLiveData<>(false);
    public MutableLiveData<Integer> year = new MutableLiveData<>(0);
    public MutableLiveData<List<YearBean>> yearBeanList = new  MutableLiveData<>(new ArrayList<>());
    public MutableLiveData<List<CreditRecordBean>> creditRecordBeanList = new  MutableLiveData<>(new ArrayList<>());
    public MutableLiveData<Integer> credit = new MutableLiveData<>(0);

    public CreditDetailViewModel(@NonNull Application application) {
        super(application);
    }

    public CreditDetailViewModel(@NonNull Application application, CreditRequest model) {
        super(application, model);
    }

    @Override
    public void onCreate() {
        super.onCreate();
        Calendar calendar = Calendar.getInstance();
        selectYear = calendar.get(Calendar.YEAR);
        year.postValue(selectYear);
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        getMyPoint();
        loadCreditRecordList();
    }

    public void getMyPoint() {
        model.getMyPoint()
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(CreditDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<CreditDetailBean>() {
                    @Override
                    public void onSuccess(CreditDetailBean resultBean) {
                        credit.postValue(resultBean.getUsableIntegral());
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

    public void loadCreditRecordList() {
        model.getCreditRecordList(incomeType, String.valueOf(selectYear), page)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(CreditDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<CreditRecordBean>() {
                    @Override
                    public void onSuccess(List<CreditRecordBean> resultBean) {
                        if (page == 1) {
                            creditRecordBeanList.postValue(resultBean);
                        } else {
                            List<CreditRecordBean> list = creditRecordBeanList.getValue();
                            list.addAll(resultBean);
                            creditRecordBeanList.postValue(list);
                        }
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {
                        totalPage = (total - 1) / 10 + 1;
                    }

                });
    }

    public void checkYear(YearBean data) {
        List<YearBean> list = new ArrayList<>();
        for (YearBean yearBean : yearBeanList.getValue()) {
            if (data.getYear().equals(yearBean.getYear())) {
                yearBean.setChecked(true);
                selectYear = yearBean.getYear();
                year.postValue(selectYear);
            } else {
                yearBean.setChecked(false);
            }
            list.add(yearBean);
        }
        yearBeanList.postValue(list);
        checkYearFlag.postValue(false);
        loadCreditRecordList();
    }

    public BindingCommand checkYear = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            checkYearFlag.postValue(true);
            yearBeanList.postValue(initYearList());
        }
    });

    private List<YearBean> initYearList() {
        List<YearBean> list = new ArrayList<>();
        Calendar calendar = Calendar.getInstance();
        Integer startYear = calendar.get(Calendar.YEAR);
        for (int i = 0; i < 5; i++) {
            YearBean yearBean = new YearBean();
            yearBean.setYear(startYear - i);
            if (selectYear == yearBean.getYear()) {
                yearBean.setChecked(true);
            } else {
                yearBean.setChecked(false);
            }
            list.add(yearBean);
        }
        Collections.reverse(list);
        return list;
    }

    public BindingCommand closeCheckYear = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            checkYearFlag.postValue(false);
        }
    });
}
