package com.xx.hbhconsumer.ui.credit;

import android.app.Application;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.CreditRequest;
import com.xx.hbhconsumer.data.http.respons.CreditGoodsDetailBean;
import com.xx.xxviewlibrary.base.xxBaseDialog;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;

public class CreditsGoodsDetailViewModel extends BaseViewModel<CreditRequest> {

    private String goodsId;

    public MutableLiveData<CreditGoodsDetailBean> creditGoodsDetailBean = new MutableLiveData<>(null);

    public CreditsGoodsDetailViewModel(@NonNull Application application) {
        super(application);
    }

    public CreditsGoodsDetailViewModel(@NonNull Application application, CreditRequest model, String goodsId) {
        super(application, model);
        this.goodsId = goodsId;
    }

    public void creditExchange(View view) {
        Integer price = creditGoodsDetailBean.getValue().getCommodityPrice();
        String integralCommodityType = creditGoodsDetailBean.getValue().getIntegralCommodityType();
        showCreditExchangeDialog(view, price, integralCommodityType);
    }

    private void showCreditExchangeDialog(View view, Integer price, String integralCommodityType) {
        CreditExchangeDialog dialog=new CreditExchangeDialog(view.getContext(), price, integralCommodityType);
        dialog.setDialogClickListener((xxBaseDialog.onDialogClickListener<Integer>) (code, data) -> creditExchange(view, price, data));
        dialog.show();
    }

    private void creditExchange(View view, Integer price, Integer num) {
        model.creditExchange(goodsId, String.valueOf(price*num), String.valueOf(num))
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(CreditsGoodsDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<Integer>() {
                    @Override
                    public void onSuccess(Integer resultBean) {
                        showCreditExchangeSuccessDialog(view, price*num);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });

    }

    private void showCreditExchangeSuccessDialog(View view, Integer total) {
        CreditExchangeSuccessDialog dialog=new CreditExchangeSuccessDialog(view.getContext(), total);
        dialog.show();
    }

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        loadGoodsDetail();
    }

    private void loadGoodsDetail() {
        model.getCreditGoodsDetail(goodsId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(CreditsGoodsDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<CreditGoodsDetailBean>() {
                    @Override
                    public void onSuccess(CreditGoodsDetailBean resultBean) {
                        creditGoodsDetailBean.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }
}
