package com.xx.hbhconsumer.ui.goods;

import android.os.Bundle;
import android.util.Log;
import android.view.View;

import androidx.fragment.app.FragmentTransaction;

import com.google.android.material.tabs.TabLayout;
import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.adapter.GoodsDescImageAdapter;
import com.xx.hbhconsumer.adapter.ImageBannerAdapter;
import com.xx.hbhconsumer.data.http.requst.GoodsRequest;
import com.xx.hbhconsumer.databinding.ActivityGoodsDetailBinding;
import com.youth.banner.indicator.CircleIndicator;

import java.util.ArrayList;
import java.util.List;

import me.goldze.mvvmhabit.base.BaseActivity;
import me.goldze.mvvmhabit.utils.StringUtils;
import me.tatarka.bindingcollectionadapter2.BR;

public class GoodsDetailActivity extends BaseActivity<ActivityGoodsDetailBinding, GoodsDetailViewModel> {

    private static final String TAG = "GoodsDetailActivity";

    private int tabSelectIndex = 0;

    private boolean firstFlag = true;

    @Override
    public void initData() {
        super.initData();
        binding.banner.addBannerLifecycleObserver(this).setIndicator(new CircleIndicator(this));
        List<String> imageUrlList = new ArrayList<>();
        ImageBannerAdapter bannerAdapter = new ImageBannerAdapter(this, imageUrlList);
        binding.banner.setAdapter(bannerAdapter);

        GoodsDescImageAdapter goodsDescImageAdapter = new GoodsDescImageAdapter(GoodsDetailActivity.this);
        viewModel.collectionState.observe(this, collectionState -> {
            if ("0".equals(collectionState)) {
                binding.ivCollectionIcon.setImageDrawable(getDrawable(R.mipmap.shangpin_icon_shoucang));
            } else {
                binding.ivCollectionIcon.setImageDrawable(getDrawable(R.mipmap.shangpin_icon_yishoucang));
            }
        });
        viewModel.goodsDetailBean.observe(this, orderBean -> {
            if (orderBean != null) {

                binding.bar.tv_title.setText(orderBean.getCommodityName());
                String price = String.valueOf(orderBean.getCommodityPrice());
                if (!StringUtils.isEmpty(price) && price.contains(".")) {
                    binding.tvPriceInteger.setText(price.split("\\.")[0]);
                    binding.tvPriceDecimal.setText("." + price.split("\\.")[1]);
                }
                binding.tvGoodsName.setText(orderBean.getCommodityName());

                if (!StringUtils.isEmpty(orderBean.getCommodityDescriptionText())) {
                    binding.tvGoodsDescText.setVisibility(View.VISIBLE);
                    binding.tvGoodsDescText.setText(orderBean.getCommodityDescriptionText());
                } else {
                    binding.tvGoodsDescText.setVisibility(View.GONE);
                }

                //把adapterset进去
                binding.rvImageList.setAdapter(goodsDescImageAdapter);
                goodsDescImageAdapter.mList = orderBean.getDetailImagesList();
                goodsDescImageAdapter.notifyDataSetChanged();
                if ("0".equals(orderBean.getCollectionStatus())) {
                    binding.ivCollectionIcon.setImageDrawable(getDrawable(R.mipmap.shangpin_icon_shoucang));
                } else {
                    binding.ivCollectionIcon.setImageDrawable(getDrawable(R.mipmap.shangpin_icon_yishoucang));
                }

                orderBean.getCommodityPictureList().forEach(item -> imageUrlList.add(item.getFilePath()));
                bannerAdapter.setDatas(imageUrlList);
                bannerAdapter.notifyDataSetChanged();
            }
        });

//        binding.tabAalTobeOverview.setOnClickListener(new View.OnClickListener() {
//            @Override
//            public void onClick(View view) {
//                binding.nsv.smoothScrollTo(0, binding.banner.getTop());
//            }
//        });
//
//        binding.tabAalTobeDetail.setOnClickListener(new View.OnClickListener() {
//            @Override
//            public void onClick(View view) {
//                binding.nsv.smoothScrollTo(0, (int) binding.tvGoodsDetailLabel.getY());
//            }
//        });

        binding.tabs.addOnTabSelectedListener(new TabLayout.OnTabSelectedListener() {
            @Override
            public void onTabSelected(TabLayout.Tab tab) {
                firstFlag = false;
                Log.i(TAG, "onTabSelected: Position = " + tab.getPosition());
                switch (tab.getPosition()) {
                    case 0:
                        tabSelectIndex = 0;
                        binding.nsv.smoothScrollTo(0, binding.banner.getTop());
                        break;
                    case 1:
                        tabSelectIndex = 1;
                        binding.nsv.smoothScrollTo(0, (int) binding.tvGoodsDetailLabel.getY());
                        break;
                    default:
                        break;
                }
            }

            @Override
            public void onTabUnselected(TabLayout.Tab tab) {
            }

            @Override
            public void onTabReselected(TabLayout.Tab tab) {
            }
        });

        binding.nsv.setOnScrollChangeListener((View.OnScrollChangeListener) (view, scrollX, scrollY, oldScrollX, oldScrollY) -> {
            Log.i(TAG, "onScrollChange: scrollY = " + scrollY);
            if (scrollY == 0) {
                firstFlag = true;
            }

            if (scrollY <= 30) {
                if (tabSelectIndex != 0 && firstFlag) {
                    binding.tabs.selectTab(binding.tabs.getTabAt(0));
                }

                binding.tabs.setScrollPosition(0, 0f, true);
            }
            if (scrollY >= binding.tabs.getBottom()) {
                if (tabSelectIndex != 1 && firstFlag) {
                    binding.tabs.selectTab(binding.tabs.getTabAt(1));
                }
                binding.tabs.setScrollPosition(1, 0f, true);
            }

        });
    }

    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_goods_detail;
    }

    @Override
    public int initVariableId() {
        return BR.goodsDetailViewModel;
    }

    @Override
    public GoodsDetailViewModel initViewModel() {
        GoodsRequest model = new GoodsRequest();
        String goodsId = getIntent().getStringExtra("goodsId");
        return new GoodsDetailViewModel(getApplication(), model, goodsId);
    }

    public interface OnScrollCallback {
        void onScrollCallback(int l, int t, int oldl, int oldt);
    }
}
