package com.xx.hbhconsumer.ui.goods;

import android.app.Application;
import android.os.Bundle;

import androidx.annotation.NonNull;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.GoodsRequest;
import com.xx.hbhconsumer.data.http.requst.PhoneRequest;
import com.xx.hbhconsumer.data.http.respons.GoodsBean;
import com.xx.hbhconsumer.data.http.respons.GoodsDetailBean;
import com.xx.hbhconsumer.ui.shop.ShopDetailActivity;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class GoodsDetailViewModel extends BaseViewModel<GoodsRequest> {

    public MutableLiveData<GoodsDetailBean> goodsDetailBean = new MutableLiveData<>(null);
    public MutableLiveData<String> collectionState = new MutableLiveData<>("0");
    private String goodsId;
    public GoodsDetailViewModel(@NonNull Application application) {
        super(application);
    }

    public GoodsDetailViewModel(@NonNull Application application, GoodsRequest model, String goodsId) {
        super(application, model);
        this.goodsId = goodsId;
    }

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        loadGoodsList();
    }

    private void loadGoodsList() {
        model.getGoodsDetail(goodsId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(GoodsDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<GoodsDetailBean>() {
                    @Override
                    public void onSuccess(GoodsDetailBean resultBean) {
                        if (resultBean != null) {
                            goodsDetailBean.postValue(resultBean);
                            collectionState.postValue(resultBean.getCollectionStatus());
                        }

                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }




                });
    }

    private void memberCollection() {
        model.memberCollection(goodsId, "0")
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(GoodsDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<String>() {
                    @Override
                    public void onSuccess(String resultBean) {
                        ToastUtils.showShort("收藏成功！");
                        collectionState.postValue("1");
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }
                });
    }

    private void cancelCollection() {
        model.memberCollection(goodsId, "1")
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(GoodsDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<String>() {
                    @Override
                    public void onSuccess(String resultBean) {
                        ToastUtils.showShort("取消收藏成功！");
                        collectionState.postValue("0");
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

    public BindingCommand goShopDetail = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            Bundle bundle = new Bundle();
            bundle.putString("merchantId", goodsDetailBean.getValue().getMerchantId());
            startActivity(ShopDetailActivity.class, bundle);
        }

    });

    public BindingCommand collect = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            if ("0".equals(collectionState.getValue())) {
                memberCollection();
            } else {
                cancelCollection();
            }

        }

    });
}
