package com.xx.hbhconsumer.ui.goods;

import android.os.Bundle;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.lifecycle.Observer;
import androidx.recyclerview.widget.GridLayoutManager;

import com.scwang.smart.refresh.layout.api.RefreshLayout;
import com.scwang.smart.refresh.layout.listener.OnLoadMoreListener;
import com.scwang.smart.refresh.layout.listener.OnRefreshListener;
import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.adapter.GoodsAdapter;
import com.xx.hbhconsumer.data.http.requst.GoodsRequest;
import com.xx.hbhconsumer.data.http.respons.GoodsBean;
import com.xx.hbhconsumer.databinding.ActivityGoodsListBinding;

import java.util.List;

import me.goldze.mvvmhabit.base.BaseActivity;
import me.tatarka.bindingcollectionadapter2.BR;

public class GoodsListActivity extends BaseActivity<ActivityGoodsListBinding, GoodsListViewModel> implements OnRefreshListener, OnLoadMoreListener {

    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_goods_list;
    }

    @Override
    public int initVariableId() {
        return BR.goodsListViewModel;
    }

    @Override
    public void initData() {
        super.initData();

        binding.refresh.setOnRefreshListener(this);
        binding.refresh.setOnLoadMoreListener(this);
        //获取适配器上下文
        GoodsAdapter goodsAdapter = new GoodsAdapter(GoodsListActivity.this);
        //获取适配器上下文
        GridLayoutManager manager = new GridLayoutManager(GoodsListActivity.this,2);
        binding.rvGoodsList.setLayoutManager(manager);
        //把adapterset进去
        binding.rvGoodsList.setAdapter(goodsAdapter);
        goodsAdapter.setOnItemClick((position, data) -> viewModel.goGoodsDetail(data.getBusinessId()));
        viewModel.goodsBeanList.observe(this, new Observer<List<GoodsBean>>() {
            @Override
            public void onChanged(List<GoodsBean> goodsBeanList) {

                if (goodsBeanList.isEmpty()) {
                    binding.rlNoData.setVisibility(View.VISIBLE);
                    binding.rvGoodsList.setVisibility(View.GONE);
                } else {
                    binding.rlNoData.setVisibility(View.GONE);
                    binding.rvGoodsList.setVisibility(View.VISIBLE);
                }
                goodsAdapter.mList = goodsBeanList;
                goodsAdapter.notifyDataSetChanged();

                if (viewModel.page == 1) {
                    binding.refresh.finishRefresh();
                } else {
                    binding.refresh.finishLoadMore();
                }
                if (viewModel.page == viewModel.totalPage) {
                    binding.refresh.setEnableLoadMore(false);
                } else {
                    binding.refresh.setEnableLoadMore(true);
                }
            }
        });
    }

    @Override
    public GoodsListViewModel initViewModel() {
        GoodsRequest model = new GoodsRequest();
        String categoryId = getIntent().getStringExtra("categoryId");
        return new GoodsListViewModel(getApplication(), model, categoryId);
    }

    @Override
    public void onLoadMore(@NonNull RefreshLayout refreshLayout) {
        viewModel.page++;
        if (viewModel.page > viewModel.totalPage) {
            binding.tvNoMore.setVisibility(View.VISIBLE);
        } else if (viewModel.page == viewModel.totalPage) {
            binding.refresh.setEnableLoadMore(false);
            viewModel.loadGoodsList();
            binding.tvNoMore.setVisibility(View.VISIBLE);
        } else {
            viewModel.loadGoodsList();
        }
    }

    @Override
    public void onRefresh(@NonNull RefreshLayout refreshLayout) {
        viewModel.page=1;
        viewModel.loadGoodsList();
        binding.refresh.setEnableLoadMore(true);
    }
}
