package com.xx.hbhconsumer.ui.goods;

import android.app.Application;
import android.os.Bundle;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.GoodsRequest;
import com.xx.hbhconsumer.data.http.respons.GoodsBean;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.ui.category.CategoryActivity;
import com.xx.hbhconsumer.ui.search.SearchActivity;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;

public class GoodsListViewModel extends BaseViewModel<GoodsRequest> {
    private static final String TAG = "SearchViewModel";
    public int page = 1;
    public int totalPage = 1;
    private String categoryId;

    public ObservableField<String> keyWord = new ObservableField<>("");
    public MutableLiveData<List<GoodsBean>> goodsBeanList = new  MutableLiveData<>(new ArrayList<>());

    public GoodsListViewModel(@NonNull Application application) {
        super(application);
    }

    public GoodsListViewModel(@NonNull Application application, GoodsRequest model, String categoryId) {
        super(application, model);
        this.categoryId = categoryId;
    }

    public void goGoodsDetail(String goodsId) {
        Bundle bundle = new Bundle();
        bundle.putString("goodsId", goodsId);
        startActivity(GoodsDetailActivity.class, bundle);
    }

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        loadGoodsList();
    }

    public void loadGoodsList() {
        model.listShopGoodsByCategory(categoryId, null, LocalData.getAffiliatedCompany(), page)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(GoodsListViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<GoodsBean>() {
                    @Override
                    public void onSuccess(List<GoodsBean> resultBean) {
                        if (page == 1) {
                            goodsBeanList.postValue(resultBean);
                        } else {
                            List<GoodsBean> list = goodsBeanList.getValue();
                            list.addAll(resultBean);
                            goodsBeanList.postValue(list);
                        }

                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {
                        totalPage = (total - 1) / 10 + 1;
                    }


                });
    }

    public BindingCommand goCategory = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(CategoryActivity.class);
        }

    });

    public BindingCommand goSearch = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            Bundle bundle = new Bundle();
            bundle.putString("keyWord", keyWord.get());
            startActivity(SearchActivity.class, bundle);
        }

    });

    public BindingCommand finishActivity = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            finish();
        }

    });


}
