package com.xx.hbhconsumer.ui.home;

import android.app.Application;
import android.os.Bundle;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.HomeRequest;
import com.xx.hbhconsumer.data.http.respons.AdvertisingBean;
import com.xx.hbhconsumer.data.http.respons.GuessLikeGoodsBean;
import com.xx.hbhconsumer.data.http.respons.HomeActivityBean;
import com.xx.hbhconsumer.data.http.respons.LowPriceGoodsBean;
import com.xx.hbhconsumer.data.http.respons.MessageBean;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.ui.activity.ActivityDetailActivity;
import com.xx.hbhconsumer.ui.credit.CreditDetailActivity;
import com.xx.hbhconsumer.ui.credit.CreditsExchangeActivity;
import com.xx.hbhconsumer.ui.goods.GoodsDetailActivity;
import com.xx.hbhconsumer.ui.hbh.HbhActivity;
import com.xx.hbhconsumer.ui.hotsales.HotSalesActivity;
import com.xx.hbhconsumer.ui.lowprice.LowPriceActivity;
import com.xx.hbhconsumer.ui.map.MapActivity;
import com.xx.hbhconsumer.ui.map.MapOverviewActivity;
import com.xx.hbhconsumer.ui.messagecenter.MessageCenterActivity;
import com.xx.hbhconsumer.ui.newproducts.NewProductsActivity;
import com.xx.hbhconsumer.ui.news.NewsDetailActivity;
import com.xx.hbhconsumer.ui.pdf.PDFWebViewActivity;
import com.xx.hbhconsumer.ui.recruit.RecruitActivity;
import com.xx.hbhconsumer.ui.search.SearchActivity;
import com.xx.hbhconsumer.ui.shop.ShopDetailActivity;
import com.xx.hbhconsumer.ui.storeservices.StoreServicesActivity;
import com.xx.xxviewlibrary.base.xxBaseDialog;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.StringUtils;

public class HomeViewModel extends BaseViewModel<HomeRequest> {
    public ObservableField<String> searchWord = new ObservableField<>("");
    public MutableLiveData<HomeActivityBean> homeActivityBean = new MutableLiveData<>(null);
    public MutableLiveData<Boolean> signFlag = new MutableLiveData<>(false);

    public MutableLiveData<Boolean> chooseAreaFlag = new MutableLiveData<>(false);
    public MutableLiveData<String> areaId = new MutableLiveData<>("1");

    public MutableLiveData<List<AdvertisingBean>> AdvertisingList = new MutableLiveData<>(new ArrayList<>());

    public MutableLiveData<List<LowPriceGoodsBean>> LowPriceGoodsList = new  MutableLiveData<>(new ArrayList<>());
    public MutableLiveData<List<GuessLikeGoodsBean>> GuessLikeGoodsList = new  MutableLiveData<>(new ArrayList<>());

    public MutableLiveData<Boolean> hasUnReadMessage = new MutableLiveData<>(false);

    public HomeViewModel(@NonNull Application application) {
        super(application);
    }

    public HomeViewModel(@NonNull Application application, HomeRequest model) {
        super(application, model);
    }

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        areaId.postValue(LocalData.getAffiliatedCompany());
        getADList();
        getMessageList();
        getLowPriceList();
        getGuessLikeGoodsList();
        getAppActivityHomePage();
    }

    public void goGoodsDetail(String goodsId) {
        Bundle bundle = new Bundle();
        bundle.putString("goodsId", goodsId);
        startActivity(GoodsDetailActivity.class, bundle);
    }

    public void goShopDetail(String merchantId) {
        Bundle bundle = new Bundle();
        bundle.putString("merchantId", merchantId);
        startActivity(ShopDetailActivity.class, bundle);
    }

    public void goNewsDetail(String url) {
        Bundle bundle = new Bundle();
        bundle.putString("newsUrl", url);
        startActivity(NewsDetailActivity.class, bundle);
    }

    public void goPdfDetail(String businessId, String url, String name) {
        model.addView(businessId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(HomeViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<String>() {
                    @Override
                    public void onSuccess(String messageBeanList) {
                        Bundle bundle = new Bundle();
                        bundle.putString("url", url);
                        bundle.putString("name", name);
                        startActivity(PDFWebViewActivity.class, bundle);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }
                });

    }

    public void getMessageList() {
        model.getMessageList(1)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(HomeViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<MessageBean>() {
                    @Override
                    public void onSuccess(List<MessageBean> messageBeanList) {
                        if (messageBeanList != null && messageBeanList.size() > 0) {
                            hasUnReadMessage.postValue(true);
                        } else {
                            hasUnReadMessage.postValue(false);
                        }
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {

                    }


                });
    }

    public void getADList() {
        model.getAdList(LocalData.getAffiliatedCompany())
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(HomeViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<List<AdvertisingBean>>() {
                    @Override
                    public void onSuccess(List<AdvertisingBean> resultBean) {
                        AdvertisingList.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }


                });
    }


    public void getLowPriceList() {
        model.getLowPriceList(LocalData.getAffiliatedCompany(), 1)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(HomeViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<LowPriceGoodsBean>() {
                    @Override
                    public void onSuccess(List<LowPriceGoodsBean> resultBean) {
                        if (resultBean != null && resultBean.size() <= 6) {
                            LowPriceGoodsList.postValue(resultBean);
                        } else if (resultBean != null && resultBean.size() > 6) {
                            LowPriceGoodsList.postValue(resultBean.subList(0, 6));
                        }
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {

                    }


                });
    }

    public void getGuessLikeGoodsList() {
        model.getGuessLikeGood(LocalData.getAffiliatedCompany())
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(HomeViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<List<GuessLikeGoodsBean>>() {
                    @Override
                    public void onSuccess(List<GuessLikeGoodsBean> resultBean) {
                        GuessLikeGoodsList.postValue(resultBean);

                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }


                });
    }


    public void memberSign(View view) {
        model.memberSign("1")
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(HomeViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<Boolean>() {
                    @Override
                    public void onSuccess(Boolean resultBean) {
                        showSignDialog(view);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }


                });
    }

    public void getAppActivityHomePage() {
        model.getAppActivityHomePageByShopId(LocalData.getAffiliatedCompany())
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(HomeViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<HomeActivityBean>() {
                    @Override
                    public void onSuccess(HomeActivityBean resultBean) {
                        homeActivityBean.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }


                });
    }

    private void showSignDialog(View view) {
        SignDialog dialog=new SignDialog(view.getContext(), 1);
        dialog.setDialogClickListener((xxBaseDialog.onDialogClickListener<SignDialog.SignCurrent>) (code, data) -> startActivity(CreditDetailActivity.class));
        dialog.show();
    }

    //跳转诉求反馈
    public BindingCommand goStoreServices = new BindingCommand(() -> startActivity(StoreServicesActivity.class));

    //跳转com.xx
    public BindingCommand goCreditsExchange = new BindingCommand(() -> startActivity(CreditsExchangeActivity.class));
    public BindingCommand goMap = new BindingCommand(() -> startActivity(MapOverviewActivity.class));
    //跳转订单管理
    public BindingCommand goRecruit = new BindingCommand(() -> startActivity(RecruitActivity.class));

    //跳转店铺信息
    public BindingCommand goHbh = new BindingCommand(() -> startActivity(HbhActivity.class));

    //跳转店铺信息
    public BindingCommand goSearch = new BindingCommand(() -> {
        Bundle bundle = new Bundle();
        bundle.putString("keyWord", searchWord.get());
        startActivity(SearchActivity.class, bundle);
    });
    public BindingCommand goLowPrice = new BindingCommand(() -> startActivity(LowPriceActivity.class));
    //跳转店铺信息
    public BindingCommand goNewProducts = new BindingCommand(() -> startActivity(NewProductsActivity.class));
    //跳转店铺信息
    public BindingCommand goHotSales = new BindingCommand(() -> startActivity(HotSalesActivity.class));

    //跳转店铺信息
    public BindingCommand goMessageCenter = new BindingCommand(() -> startActivity(MessageCenterActivity.class));

    public BindingCommand chooseArea = new BindingCommand(() -> chooseAreaFlag.postValue(!chooseAreaFlag.getValue()));
    public BindingCommand closeChooseArea = new BindingCommand(() -> chooseAreaFlag.postValue(false));

    public BindingCommand goActivityDetail = new BindingCommand(() -> {
        Bundle bundle = new Bundle();
        bundle.putString("activityUrl", homeActivityBean.getValue().getActivityUrl());
        startActivity(ActivityDetailActivity.class, bundle);
    });

    public BindingCommand changeBinghai = new BindingCommand(() -> {
        areaId.postValue("2");
        LocalData.saveAffiliatedCompany("2");
        chooseAreaFlag.postValue(false);

        getADList();
        getMessageList();
        getLowPriceList();
        getGuessLikeGoodsList();
        getAppActivityHomePage();
    });
    public BindingCommand changeHexi = new BindingCommand(() -> {
        areaId.postValue("1");
        LocalData.saveAffiliatedCompany("1");
        chooseAreaFlag.postValue(false);

        getADList();
        getMessageList();
        getLowPriceList();
        getGuessLikeGoodsList();
        getAppActivityHomePage();
    });
}
