package com.xx.hbhconsumer.ui.login

import android.content.Context
import android.content.Intent
import android.net.Uri
import android.os.Bundle
import android.provider.Settings
import androidx.lifecycle.Observer
import androidx.recyclerview.widget.GridLayoutManager
import com.jakewharton.rxbinding3.widget.checked
import com.jakewharton.rxbinding3.widget.checkedChanges
import com.tbruyelle.rxpermissions3.RxPermissions
import com.xx.hbhconsumer.BR
import com.xx.hbhconsumer.R
import com.xx.hbhconsumer.adapter.CollectionGoodsAdapter
import com.xx.hbhconsumer.data.http.requst.LoginRequest
import com.xx.hbhconsumer.data.http.respons.CollectionBean
import com.xx.hbhconsumer.databinding.ActivityLoginBinding
import com.xx.xxviewlibrary.comm.CommTextAgreeDialog
import com.xx.xxviewlibrary.comm.CommTextDialog
import com.xx.xxviewlibrary.comm.RefuseDialogBean
import me.goldze.mvvmhabit.base.BaseActivity
import me.goldze.mvvmhabit.utils.SPUtils
import me.goldze.mvvmhabit.utils.ToastUtils

class LoginActivity() : BaseActivity<ActivityLoginBinding, LoginViewModel>() {


    override fun initContentView(savedInstanceState: Bundle?): Int {

        return R.layout.activity_login

    }

    override fun initVariableId(): Int {
        return BR.loginViewModel
    }

    /*声明协议内容*/
    var agreementContext: String = ""
    override fun initData() {

//        检查版本
        viewModel.rxPermissions = RxPermissions(this)
        // 获得协议内容
        viewModel.getProtocols()
        SPUtils.getInstance().clear()
        super.initData()

        // 使用SharedPreferences检查是否是第一次打开应用
        val preferences = getPreferences(Context.MODE_PRIVATE)
        val isAgreeFlag = preferences.getBoolean("is_agree_flag", true)
        if (isAgreeFlag) {
            // 如果是第一次打开应用，执行相应的操作
//            ToastUtils.showShort("第一次登录")
            viewModel.agreeContent.observe(this) { agreeContent: String? ->
                if (agreeContent != null) {
                    agreementContext = agreeContent
//                    在这里加上隐私协议弹窗
                    showCommTextAgreeDialog(
                        RefuseDialogBean(agreementContext, "同意", "不同意", "隐私条款"),
                        object : CommTextDialog.onAcceptCallBack, CommTextAgreeDialog.onAcceptCallBack {
                            override fun refuseBack() {
                                finish()
                                val intent = Intent(Intent.ACTION_MAIN)
                                intent.addCategory(Intent.CATEGORY_HOME)
                                intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK
                                startActivity(intent)
                            }

                            override fun acceptBack() {
                                // 设置is_agree_flag标记为false，表示隐私协议已同意
                                val editor = preferences.edit()
                                editor.putBoolean("is_agree_flag", false)
                                editor.apply()
                                viewModel.checkVersion(binding.root.rootView)
                            }
                        })
                }
            }
        }else{
            viewModel.checkVersion(binding.root.rootView)
        }


        //安装新版本
        viewModel.openInstall.observe(this, Observer<String?> {
            fun onChanged(s: String) {
                if ("1" == s) {
                    val packageURI = Uri.parse("package:" + applicationContext.packageName)
                    val intent = Intent(Settings.ACTION_MANAGE_UNKNOWN_APP_SOURCES, packageURI)
                    startActivityForResult(intent, 1024)
                }
            }
        })

        viewModel.consentAgreementFlag.observe(this,
            Observer<Boolean> { consentAgreementFlag ->
                if (binding.rbLoginAgreement.isSelected) {
                    binding.radioSelectedGroup.clearCheck()
                } else {
                    binding.rbLoginAgreement.setSelected(consentAgreementFlag)
                }
            })


    }

    override fun initViewObservable() {
        super.initViewObservable()
    }

    override fun initViewModel(): LoginViewModel {
        val lm: LoginRequest = LoginRequest()
        return LoginViewModel(application, lm)
    }

}