package com.xx.hbhconsumer.ui.main;

import static me.goldze.mvvmhabit.utils.Utils.Interceptor_TOKEN;

import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.KeyEvent;
import android.widget.Toast;

import androidx.fragment.app.Fragment;

import com.google.android.material.bottomnavigation.BottomNavigationView;
import com.xx.hbhconsumer.BR;
import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.data.http.requst.HomeRequest;
import com.xx.hbhconsumer.data.http.requst.MapRequest;
import com.xx.hbhconsumer.databinding.ActivityMainBinding;
import com.xx.hbhconsumer.ui.activity.ActivityFragment;
import com.xx.hbhconsumer.ui.category.CategoryActivity;
import com.xx.hbhconsumer.ui.goods.GoodFragment;
import com.xx.hbhconsumer.ui.home.HomeFragment;
import com.xx.hbhconsumer.ui.login.LoginActivity;
import com.xx.hbhconsumer.ui.map.MapViewModel;
import com.xx.hbhconsumer.ui.mine.MineFragment;
import com.xx.hbhconsumer.ui.shop.ShopFragment;
import com.xx.xxviewlibrary.base.AppManager;

import me.goldze.mvvmhabit.base.BaseActivity;

public class MainActivity extends BaseActivity<ActivityMainBinding, MainViewModel> {

    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_main;
    }


    @Override
    public void initData() {
        super.initData();
        // 获取Intent对象
        Intent intent = getIntent();

        // 从Intent中获取传递的额外信息
        if (intent != null) {
            String logFlag = intent.getStringExtra("logFlag");
            if (logFlag != null) {
                Log.v("首页按钮登录","");
            }else {
                Log.v("直接登录首页","");
                // 获取SharedPreferences实例
                SharedPreferences sharedPreferences = getSharedPreferences("AppNamePreferences", Context.MODE_PRIVATE);

                // 从SharedPreferences中获取用户名和密码
                String username = sharedPreferences.getString("username", null);
                String password = sharedPreferences.getString("password", null);
                String token = sharedPreferences.getString("token", null);
                // 检查是否成功获取到用户名和密码
                if (username != null && password != null) {
                    Log.v("刚开始获取的账号:", username);
                    Log.v("刚开始获取的密码:", password);
                    Log.v("刚开始获取的token:", token);
                    Interceptor_TOKEN = token;
                    viewModel.getLogin(username,password);

                }else {
                    Log.v("账号密码为空跳转登录页","");
                    startActivity(LoginActivity.class);
                    finish();
                }
            }
        }

        // 初始化底部导航栏
        BottomNavigationView bottomNavigationView = findViewById(R.id.bottom_navigation_view);
        bottomNavigationView.setOnNavigationItemSelectedListener(navItemSelectedListener);

        Integer fragmentIndex = getIntent().getIntExtra("fragmentIndex", -1);

        if (fragmentIndex == 2) {
            getSupportFragmentManager().beginTransaction().replace(R.id.fragment_container, new ActivityFragment()).commit();
        } else {
            // 显示默认的 Fragment
            getSupportFragmentManager().beginTransaction().replace(R.id.fragment_container, new HomeFragment()).commit();
        }


    }
    @Override
    public int initVariableId() {
        return BR.mainViewModel;
    }

    @Override
    public void onPointerCaptureChanged(boolean hasCapture) {
        super.onPointerCaptureChanged(hasCapture);
    }


    private final BottomNavigationView.OnNavigationItemSelectedListener navItemSelectedListener = item -> {
        Fragment selectedFragment = null;

        // 根据选项 ID 创建相应的 Fragment

        if (item.getItemId() == R.id.menu_home) {
            selectedFragment = new HomeFragment();
        } else if (item.getItemId() == R.id.menu_shop) {
            selectedFragment = new ShopFragment();
        } else if (item.getItemId() == R.id.menu_activity) {
            selectedFragment = new ActivityFragment();
        } else if (item.getItemId() == R.id.menu_good) {
            selectedFragment = new GoodFragment();
        } else if (item.getItemId() == R.id.menu_shopping_cart) {
            selectedFragment = new MineFragment();
        }


        // 替换当前显示的 Fragment
        // 确保选择项不能为空
        assert selectedFragment != null;
        getSupportFragmentManager().beginTransaction().replace(R.id.fragment_container, selectedFragment).commit();
        return true;
    };

    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (keyCode == KeyEvent.KEYCODE_BACK) {
            viewModel.showExitDialog();
            return false;
        }
        return super.onKeyDown(keyCode, event);
    }

    @Override
    public MainViewModel initViewModel() {
        HomeRequest loginRequest = new HomeRequest();
        return new MainViewModel(this, getApplication(), loginRequest);
    }

}
