package com.xx.hbhconsumer.ui.main;

import static me.goldze.mvvmhabit.utils.Utils.Interceptor_TOKEN;
import static me.goldze.mvvmhabit.utils.Utils.getContext;

import android.app.Application;
import android.content.Context;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.util.Log;
import android.view.View;

import androidx.annotation.NonNull;
import com.xx.hbhconsumer.data.http.requst.HomeRequest;
import com.xx.hbhconsumer.data.http.respons.UserInfoBean;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.data.staticdata.StaticData;
import com.xx.hbhconsumer.ui.home.HomeViewModel;
import com.xx.hbhconsumer.ui.login.LoginActivity;
import com.xx.hbhconsumer.ui.login.LoginViewModel;
import com.xx.hbhconsumer.ui.pwd.PwdActivity;
import com.xx.hbhconsumer.ui.settings.LogoutDialog;
import com.xx.xxviewlibrary.base.AppManager;
import com.xx.xxviewlibrary.base.xxBaseDialog;
import com.xx.xxviewlibrary.comm.CommTextDialog;
import com.xx.xxviewlibrary.comm.RefuseDialogBean;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.StringUtils;

public class MainViewModel extends BaseViewModel<HomeRequest> {

    private Context context;

    public MainViewModel(@NonNull Application application) {
        super(application);
    }

    public MainViewModel(Context context, @NonNull Application application, HomeRequest model) {
        super(application, model);
        this.context = context;
    }

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        String affiliatedCompany = LocalData.getAffiliatedCompany();
        if (StringUtils.isEmpty(affiliatedCompany)) {
            LocalData.saveAffiliatedCompany("1");
        }
    }

    public void exit() {
        AppManager.getAppManager().AppExit();
    }

    public void showExitDialog() {
        ExitDialog dialog = new ExitDialog(context, this);
        dialog.setDialogClickListener((xxBaseDialog.onDialogClickListener<LogoutDialog>) (code, data) -> AppManager.getAppManager().AppExit());
        dialog.show();
    }

    public void getLogin(String username,String password){

        model.login(username, password)
                .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                .doOnSubscribe(MainViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                        showDialog("正在请求...");
                    }
                }).subscribe(new ApiDisposableObserver<String>() {
                    @Override
                    public void onSuccess(String resultBean) {
                        //是指token
                        Interceptor_TOKEN = "Bearer " + resultBean;
                        SharedPreferences sharedPreferences = getContext().getSharedPreferences("AppNamePreferences", Context.MODE_PRIVATE);
                        SharedPreferences.Editor editor = sharedPreferences.edit();
                        editor.putString("username", username);
                        editor.putString("password", password);
                        editor.putString("token", Interceptor_TOKEN);
                        editor.apply();
                        getuserInfo();
//                                startActivity(HomeActivity.class);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

    /**
     * 获取用户信息
     */
    public void getuserInfo() {
        model.getUserInfo()
                .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                .doOnSubscribe(MainViewModel.this)
                .doOnSubscribe (new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<UserInfoBean>() {
                    @Override
                    public void onSuccess(UserInfoBean resultBean) {
                        LocalData.saveToken(Interceptor_TOKEN);
                        //将用户信息存储到本地
                        LocalData.saveUser(resultBean.getUser());
                        dismissDialog();
                        if (resultBean.getUser().getNeedChangeTimeLongPassword()) {
                            Bundle bundle = new Bundle();
                            bundle.putBoolean("needChangeTimeLongPassword", true);
                            startActivity(PwdActivity.class, bundle);
                            finish();
                        } else {
                     /*       startActivity(MainActivity.class);
                            finish();*/
                        }



                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }


                });
    }

    /**
     * 密码超期显示
     */
    public void ShowOverDueDialog() {
        showCommTextDialog(new RefuseDialogBean("您的密码使用时间过长,请修改密码后重新登录", "修改密码", "取消", "温馨提示"), new CommTextDialog.onAcceptCallBack() {
            @Override
            public void refuseBack() {
                /*跳转到首页(首先获取用户信息)*/
                model.getUserInfo()
                        .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                        .doOnSubscribe(MainViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
                            }
                        }).subscribe(new ApiDisposableObserver<UserInfoBean>() {
                            @Override
                            public void onSuccess(UserInfoBean resultBean) {

                                //将用户信息存储到本地
                                LocalData.saveUser(resultBean.getUser());
                                /*在登录的时候就给staticData的消息标志位设置成未读*/
                                StaticData.flag = 0;
                                dismissDialog();
                                LocalData.saveMerchant(resultBean.getMerchant());
//                                startActivity(HomeActivity.class);
                            }

                            @Override
                            public void onError(String Error) {
                                dismissDialog();
                            }
                        });
            }


            @Override
            public void acceptBack() {
                /*跳转到修改密码页面*/
                startActivity(PwdActivity.class);
            }
        });

    }
}
