package com.xx.hbhconsumer.ui.map;

import android.graphics.Bitmap;
import android.graphics.Matrix;
import android.graphics.drawable.BitmapDrawable;
import android.os.Bundle;
import android.os.Handler;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.LinearLayout;
import android.widget.RadioButton;
import android.widget.RadioGroup;
import android.widget.Toast;

import com.fengmap.android.FMErrorMsg;
import com.fengmap.android.analysis.navi.FMNaviAnalyser;
import com.fengmap.android.analysis.navi.FMNaviResult;
import com.fengmap.android.analysis.navi.FMRouteSetting;
import com.fengmap.android.analysis.search.FMSearchAnalyser;
import com.fengmap.android.exception.FMObjectException;
import com.fengmap.android.map.FMGroupInfo;
import com.fengmap.android.map.FMMap;
import com.fengmap.android.map.FMMapInfo;
import com.fengmap.android.map.FMMapUpgradeInfo;
import com.fengmap.android.map.FMMapView;
import com.fengmap.android.map.FMPickMapCoordResult;
import com.fengmap.android.map.animator.FMLinearInterpolator;
import com.fengmap.android.map.event.OnFMMapClickListener;
import com.fengmap.android.map.event.OnFMMapInitListener;
import com.fengmap.android.map.event.OnFMSwitchGroupListener;
import com.fengmap.android.map.geometry.FMMapCoord;
import com.fengmap.android.map.layer.FMImageLayer;
import com.fengmap.android.map.layer.FMLineLayer;
import com.fengmap.android.map.marker.FMImageMarker;
import com.fengmap.android.map.marker.FMLineMarker;
import com.fengmap.android.map.marker.FMModel;
import com.fengmap.android.map.marker.FMSegment;
import com.fengmap.android.utils.FMLog;
import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.adapter.MapAdapter;
import com.xx.hbhconsumer.adapter.SearchBarAdapter;
import com.xx.hbhconsumer.data.http.requst.MapRequest;
import com.xx.hbhconsumer.databinding.ActivityMapBinding;
import com.xx.hbhconsumer.utils.AnalysisUtils;
import com.xx.hbhconsumer.utils.KeyBoardUtils;
import com.xx.hbhconsumer.utils.ViewHelper;

import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.HashMap;

import me.goldze.mvvmhabit.base.BaseActivity;
import me.goldze.mvvmhabit.utils.StringUtils;
import me.tatarka.bindingcollectionadapter2.BR;

public class MapActivity extends BaseActivity<ActivityMapBinding, MapViewModel> implements OnFMMapInitListener,SearchBar.OnSearchResultCallback,
        AdapterView.OnItemClickListener, OnFMMapClickListener, CompoundButton.OnCheckedChangeListener {
    private static final String TAG = "MapActivity";
    private Handler mHandler = new Handler();
    private CheckBox mGroupControl;
    private RadioButton[] mRadioButtons;
    /**
     * 线图层
     */
    protected FMLineLayer mLineLayer;
    /**
     * 导航分析
     */
    protected FMNaviAnalyser mNaviAnalyser;
    /**
     * 起点坐标
     */
    protected FMMapCoord mSartCoord;
    /**
     * 起点楼层
     */
    protected int mStartGroupId;
    /**
     * 起点图层
     */
    protected FMImageLayer mStartImageLayer;
    /**
     * 终点坐标
     */
    protected FMMapCoord mEndCoord;
    /**
     * 终点楼层id
     */
    protected int mEndGroupId;
    /**
     * 终点图层
     */
    protected FMImageLayer mEndImageLayer;
    private SearchBarAdapter mSearchAdapter;
    protected HashMap<Integer, FMImageLayer> mImageLayers = new HashMap<>();
    FMMap mFMMap;
    private FMModel mLastClicked;
    //默认楼层
    private int mGroupId = 4;
    protected FMSearchAnalyser mSearchAnalyser;
    private SearchBar mSearchBar;

    private boolean firstLoadSuccess = false;

    private FMMapView fmMapView;

    private Matrix matrix = new Matrix();

    ArrayList<FMGroupInfo> groups;

    LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(
            LinearLayout.LayoutParams.MATCH_PARENT, // 宽度
            LinearLayout.LayoutParams.MATCH_PARENT  // 高度
    );

    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_map;
    }
    @Override
    public void initData() {
        super.initData();
        viewModel.maptyep=getIntent().getStringExtra("mapId");
        viewModel.checkMapFlag.observe(this, checkMapFlag -> {
            if (checkMapFlag) {
                binding.rlCheckYear.setVisibility(View.VISIBLE);
                Bitmap bitmap = ((BitmapDrawable) getDrawable(R.mipmap.home_icon_xiajiantou)).getBitmap();
                // 设置旋转角度
                matrix.setRotate(180f);
                // 重新绘制Bitmap
                bitmap = Bitmap.createBitmap(bitmap, 0, 0, bitmap.getWidth(),bitmap.getHeight(), matrix, true);
                binding.ivChooseIcon.setImageBitmap(bitmap);
            } else {
                binding.rlCheckYear.setVisibility(View.GONE);
                binding.ivChooseIcon.setImageDrawable(getDrawable(R.mipmap.home_icon_xiajiantou));
            }
        });

        MapAdapter yearAdapter = new MapAdapter(this);
        binding.rvYearList.setAdapter(yearAdapter);
        yearAdapter.setOnItemClick((position, data) -> {

            Log.i(TAG, "initData: onDestroy");
            viewModel.checkMap(data);
        });
        viewModel.mapList.observe(this, yearBeanList -> {
            yearAdapter.mList = yearBeanList;
            yearAdapter.notifyDataSetChanged();
        });

        viewModel.region.observe(this, region -> {
            binding.tvRegion.setText(region);
        });

        //搜索框
        mSearchBar = ViewHelper.getView(MapActivity.this, R.id.search_title_bar);
        mSearchBar.setOnSearchResultCallback(this);
        mSearchBar.setOnItemClickListener(this);

        viewModel.mapId.observe(this, mapId -> {
            if (StringUtils.isEmpty(mapId)) {
                return;
            }
            if (firstLoadSuccess) {
                mFMMap.onDestroy();
            }
            mStartImageLayer = null;
            mEndImageLayer = null;
            fmMapView = new FMMapView(this);
            fmMapView.setLayoutParams(params);
            binding.llMapView.removeAllViews();
            binding.llMapView.addView(fmMapView);
            mFMMap = fmMapView.getFMMap();       //获取地图操作对象
            mFMMap.setOnFMMapInitListener(this);
            mFMMap.setOnFMMapClickListener(this);
            mFMMap.openMapById(mapId, true);          //打开地图
        });
    }
    @Override
    public int initVariableId() {
        return BR.mapViewModel;
    }
    @Override
    public void onBackPressed() {
        if (mFMMap != null) {
            mFMMap.onDestroy();
        }
        super.onBackPressed();
    }
    @Override
    public void initParam() {
        super.initParam();


    }

    /**
     * 通过关键字查询模型
     *
     * @param keyword 关键字
     */
    private ArrayList<FMModel> queryModelByKeyword(String keyword) {
        //查询楼层集合
        int[] groupIds = {mFMMap.getFocusGroupId()};
        //搜索请求
        return AnalysisUtils.queryModelByKeyword(mFMMap, groupIds, mSearchAnalyser, keyword);
    }

    protected void clearImageMarker() {
        for (FMImageLayer imageLayer : mImageLayers.values()) {
            imageLayer.removeAll();
        }
    }

    /**
     * 地图加载成功回调事件
     *
     * @param path 地图所在sdcard路径
     */
    @Override
    public void onMapInitSuccess(String path) {
        firstLoadSuccess = true;
        //线图层
        mLineLayer = mFMMap.getFMLayerProxy().getFMLineLayer();
        mFMMap.addLayer(mLineLayer);

        FMMapInfo mapInfo = mFMMap.getFMMapInfo();
        groups = mapInfo.getGroups();
        displayGroupView(groups);

        //图片图层
        int groupSize = mFMMap.getFMMapInfo().getGroupSize();
        mImageLayers = new HashMap<>();
        for (int i = 0; i < groupSize; i++) {
            int groupId = mFMMap.getMapGroupIds()[i];
            FMImageLayer imageLayer = mFMMap.getFMLayerProxy().getFMImageLayer(groupId);

            mImageLayers.put(groupId, imageLayer);
        }

        //搜索分析
        try {
            mSearchAnalyser = FMSearchAnalyser.getFMSearchAnalyserById(viewModel.mapId.getValue());
        } catch (FMObjectException e) {
            e.printStackTrace();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }

        //导航分析
        try {
            mNaviAnalyser = FMNaviAnalyser.getFMNaviAnalyserById(viewModel.mapId.getValue());
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (FMObjectException e) {
            e.printStackTrace();
        }
    }

    @Override
    public void onMapInitFailure(String s, int errorCode) {
        FMLog.le("onMapInitFailure", FMErrorMsg.getErrorMsg(errorCode));
    }

    @Override
    public boolean onUpgrade(FMMapUpgradeInfo fmMapUpgradeInfo) {
        return false;
    }

    @Override
    public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
        //关闭软键盘
        KeyBoardUtils.closeKeybord(mSearchBar.getCompleteText(), MapActivity.this);

        FMModel model = (FMModel) parent.getItemAtPosition(position);
        //切换楼层
        int groupId = model.getGroupId();

        if (groupId != mFMMap.getFocusGroupId()) {
            mFMMap.setFocusByGroupId(groupId, null);
            for (int i = 0; i < groups.size(); i++) {
                mRadioButtons[i].setChecked(false);
            }
            mRadioButtons[groupId-1].setChecked(true);

        }

        //移动至中心点
        FMMapCoord mapCoord = model.getCenterMapCoord();
        mFMMap.moveToCenter(mapCoord, false);

        clearImageMarker();
        //添加图片
        FMImageMarker imageMarker = ViewHelper.buildImageMarker(getResources(), mapCoord);
        mImageLayers.get(model.getGroupId()).addMarker(imageMarker);

        clearFocus(model);
    }

    @Override
    public void onSearchCallback(String keyword) {
        //地图未显示前，不执行搜索事件
        boolean isCompleted = mFMMap.getMapFirstRenderCompleted();
        if (!isCompleted) {
            return;
        }

        // 搜索model的中文字段
        ArrayList<FMModel> models = AnalysisUtils.queryModelByKeyword(mFMMap, mSearchAnalyser, keyword);
//        Toast.makeText(this, "结果：" + models.size(), Toast.LENGTH_SHORT).show();
//        if (mSearchAdapter == null) {
            mSearchAdapter = new SearchBarAdapter(MapActivity.this, models);
            mSearchBar.setAdapter(mSearchAdapter);
//        } else {
//            mSearchAdapter.setDatas(models);
//            mSearchAdapter.notifyDataSetChanged();
//        }
    }

    /**
     * 清除模型的聚焦效果
     *
     * @param model 模型
     */
    private void clearFocus(FMModel model) {
        if (!model.equals(mLastClicked)) {
            if (mLastClicked != null) {
                mLastClicked.setSelected(false);
            }
            this.mLastClicked = model;
            this.mLastClicked.setSelected(true);
        }
    }

    private void mapClick(float x, float y) {
        // 获取屏幕点击位置的地图坐标
        final FMPickMapCoordResult mapCoordResult = mFMMap.pickMapCoord(x, y);
        if (mapCoordResult == null) {
            return;
        }

        // 起点
        if (mSartCoord == null) {
            clear();

            mSartCoord = mapCoordResult.getMapCoord();
            mStartGroupId = mapCoordResult.getGroupId();
            createStartImageMarker();
            return;
        }

        // 终点
        if (mEndCoord == null) {
            mEndCoord = mapCoordResult.getMapCoord();
            mEndGroupId = mapCoordResult.getGroupId();
            createEndImageMarker();
        }

        analyzeNavigation();

        // 画完置空
        mSartCoord = null;
        mEndCoord = null;
    }

    @Override
    public void onMapClick(float x, float y) {
        mapClick(x,y);
    }

    /**
     * 开始分析导航
     */
    private void analyzeNavigation() {
        FMRouteSetting fmRouteSetting = new FMRouteSetting();
        fmRouteSetting.setRouteCrossGroupPriority(FMNaviAnalyser.FMRouteCrossGroupPriority.ROUTE_CGP_ESCALATOR_FIRST);
        fmRouteSetting.setNaviModule(FMNaviAnalyser.FMNaviModule.MODULE_SHORTEST);
        int type = mNaviAnalyser.analyzeNavi(mStartGroupId, mSartCoord, mEndGroupId, mEndCoord, fmRouteSetting);
        if (type == FMNaviAnalyser.FMRouteCalcuResult.ROUTE_SUCCESS) {
            addLineMarker();
        }
    }

    /**
     * 添加线标注
     */
    protected void addLineMarker() {
        ArrayList<FMNaviResult> results = mNaviAnalyser.getNaviResults();
        // 填充导航数据
        ArrayList<FMSegment> segments = new ArrayList<>();
        for (FMNaviResult r : results) {
            int groupId = r.getGroupId();
            FMSegment s = new FMSegment(groupId, r.getPointList());
            segments.add(s);
        }
        //添加LineMarker
        FMLineMarker lineMarker = new FMLineMarker(segments);
        lineMarker.setLineWidth(6f);
        mLineLayer.addMarker(lineMarker);
    }

    /**
     * 创建起点图标
     */
    protected void createStartImageMarker() {
        clearStartImageLayer();
        // 添加起点图层
        mStartImageLayer = mFMMap.getFMLayerProxy().getFMImageLayer(mStartGroupId);
        // 标注物样式
        FMImageMarker imageMarker = ViewHelper.buildImageMarker(getResources(), mSartCoord, R.mipmap.ic_marker_start);
        mStartImageLayer.addMarker(imageMarker);
    }

    /**
     * 创建终点图层
     */
    protected void createEndImageMarker() {
        clearEndImageLayer();
        // 添加起点图层
        mEndImageLayer = mFMMap.getFMLayerProxy().getFMImageLayer(mEndGroupId);
        // 标注物样式
        FMImageMarker imageMarker = ViewHelper.buildImageMarker(getResources(), mEndCoord, R.mipmap.ic_marker_end);
        mEndImageLayer.addMarker(imageMarker);
    }
    /**
     * 清除线图层
     */
    protected void clearLineLayer() {
        if (mLineLayer != null) {
            mLineLayer.removeAll();
        }
    }

    /**
     * 清除起点图层
     */
    protected void clearStartImageLayer() {
        if (mStartImageLayer != null) {
            mStartImageLayer.removeAll();
            mFMMap.removeLayer(mStartImageLayer); // 移除图层
            mStartImageLayer = null;
        }
    }

    /**
     * 清除终点图层
     */
    protected void clearEndImageLayer() {
        if (mEndImageLayer != null) {
            mEndImageLayer.removeAll();
            mFMMap.removeLayer(mEndImageLayer); // 移除图层

            mEndImageLayer = null;
        }
    }
    protected void clear() {
        clearLineLayer();
        clearStartImageLayer();
        clearEndImageLayer();
    }

    /**
     * 展示地图楼层
     *
     * @param groups 地图楼层信息
     */
    private void displayGroupView(ArrayList<FMGroupInfo> groups) {
        RadioGroup radioGroup = ViewHelper.getView(MapActivity.this, R.id.rg_groups);
        for (int i = 0; i < radioGroup.getChildCount(); i++) {
            RadioButton radioButton = (RadioButton) radioGroup.getChildAt(i);
            radioButton.setTag("");
            radioButton.setText("");
            radioButton.setOnCheckedChangeListener(null);
        }
        int count = groups.size();
        mRadioButtons = new RadioButton[count];

        for (int i = 0; i < count; i++) {
            int position = radioGroup.getChildCount() - i - 1;
            mRadioButtons[i] = (RadioButton) radioGroup.getChildAt(position);

            FMGroupInfo groupInfo = groups.get(i);
            mRadioButtons[i].setTag(groupInfo.getGroupId());
            mRadioButtons[i].setText(groupInfo.getGroupName().toUpperCase());
            mRadioButtons[i].setOnCheckedChangeListener(MapActivity.this);
        }
        mRadioButtons[count - 1].setChecked(true);

        //单、多层控制
        mGroupControl = ViewHelper.getView(MapActivity.this, R.id.cb_groups);
        mGroupControl.setOnCheckedChangeListener(new CheckBox.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                if (isChecked) {
                    mGroupControl.setText(R.string.title_groups_multi);
                    multiDisplayFloor();
                } else {
                    mGroupControl.setText(R.string.title_groups_single);
                    singleDisplayFloor();
                }
            }
        });
    }

    /**
     * 多层显示
     *
     * @param groupId 焦点层id
     */
    private void multiDisplayFloor(int groupId) {
        int[] showFloors = mFMMap.getMapGroupIds();
        // 设置多层显示,及焦点层
        int focus = convertToFocus(groupId);
        mFMMap.setMultiDisplay(showFloors, focus, null);
    }

    /**
     * 多层显示
     */
    private void multiDisplayFloor() {
        int focusGroupId = mFMMap.getFocusGroupId();
        multiDisplayFloor(focusGroupId);
    }
    /**
     * 焦点层id转换成焦点层索引
     *
     * @param focusGroupId 焦点层id
     * @return
     */
    private int convertToFocus(int focusGroupId) {
        FMMapInfo mapInfo = mFMMap.getFMMapInfo();
        int size = mapInfo.getGroups().size();
        int focus = 0;
        for (int i = 0; i < size; i++) {
            int groupId = mapInfo.getGroups().get(i).getGroupId();
            if (focusGroupId == groupId) {
                focus = i;
                break;
            }
        }
        return focus;
    }

    /**
     * 单层显示
     */
    private void singleDisplayFloor() {
        int groupId = mFMMap.getFocusGroupId();
        singleDisplayFloor(groupId);
    }

    /**
     * 单层显示
     *
     * @param groupId 楼层id
     */
    private void singleDisplayFloor(int groupId) {
        int[] showFloors = new int[1]; // 需要显示的楼层
        showFloors[0] = groupId;
        // 设置单层显示,及焦点层
        mFMMap.setMultiDisplay(showFloors, 0, null);
    }

    @Override
    public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
        if (isChecked) {
            int groupId = (int) buttonView.getTag();
            mFMMap.setFocusByGroupIdAnimated(groupId, new FMLinearInterpolator(), new OnFMSwitchGroupListener() {
                @Override
                public void beforeGroupChanged() {
                    setRadioButtonEnable(false);
                }

                @Override
                public void afterGroupChanged() {
                    setRadioButtonEnable(true);
                }
            });
        }
    }

    /**
     * 设置楼层是否可用
     *
     * @param enable true 可以被点击
     *               false 不可被点击
     */
    private void setRadioButtonEnable(final boolean enable) {
        mHandler.post(new Runnable() {
            @Override
            public void run() {
                for (int i = 0; i < mRadioButtons.length; i++) {
                    mRadioButtons[i].setEnabled(enable);
                }
            }
        });
    }


    @Override
    public MapViewModel initViewModel() {
        MapRequest loginRequest = new MapRequest();
        return new MapViewModel(getApplication(), loginRequest);
    }
}
