package com.xx.hbhconsumer.ui.mine;

import static com.xx.hbhconsumer.utils.RetrofitClient.baseImgUrl;

import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.Nullable;
import androidx.lifecycle.Observer;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.resource.bitmap.RoundedCorners;
import com.bumptech.glide.load.resource.drawable.DrawableTransitionOptions;
import com.bumptech.glide.request.RequestOptions;
import com.xx.hbhconsumer.BR;
import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.data.http.requst.MineRequest;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.databinding.FragmentMineBinding;
import com.xx.hbhconsumer.utils.RetrofitClient;

import me.goldze.mvvmhabit.base.BaseFragment;
import me.goldze.mvvmhabit.utils.StringUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;
import me.jessyan.autosize.utils.AutoSizeUtils;

public class MineFragment extends BaseFragment<FragmentMineBinding, MineViewModel> {


    @Override
    public int viewModelType() {
        return 1;
    }

    @Override
    public int initContentView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        return R.layout.fragment_mine;
    }
    @Override
    public void onResume() {
        super.onResume();
    }
    @Override
    public int initVariableId() {
        return BR.mineViewModel;
    }

    //    重写初始方法调用参数
    @Override
    public void initData() {
        super.initData();
        viewModel.integralTotal.observe(this, integralTotal -> binding.tvPoint.setText(String.valueOf(integralTotal)));
        viewModel.memberCoupon.observe(this, memberCoupon -> binding.tvCouponNum.setText(String.valueOf(memberCoupon)));
        viewModel.memberName.observe(this, memberName -> binding.tvMemberName.setText(memberName));

        /*控制台拿到了图片路径了*/
        /*如果图片有刷新就会进行更新*/
        viewModel.avatarImageUrl.observe(this, new Observer<String>() {
            @Override
            public void onChanged(String imageUrl) {
                if (!StringUtils.isEmpty(imageUrl)) {
                    // 设置圆角半径
                    int radius = 120;
                    // 创建圆角转换器
                    RoundedCorners roundedCorners = new RoundedCorners(radius);
                    // 创建Glide请求选项
                    RequestOptions requestOptions = RequestOptions.bitmapTransform(roundedCorners);
                    // 使用Glide加载图片并应用圆角转换器
                    Glide.with(MineFragment.this)
                            .load(baseImgUrl + imageUrl)
                            .apply(requestOptions)
                            .transition(DrawableTransitionOptions.withCrossFade())
                            .into(binding.ivAvatar);
                } else {

                }
            }
        });
        viewModel.collectionBean.observe(this, collectionBean -> {
            if (collectionBean != null) {
                ViewGroup.LayoutParams layoutParams = binding.ivCollectionImg.getLayoutParams();
                // 设置ImageView的新宽度和高度
                layoutParams.width = AutoSizeUtils.dp2px(getActivity(), 50F);
                layoutParams.height = AutoSizeUtils.dp2px(getActivity(), 50F);
                binding.ivCollectionImg.setLayoutParams(layoutParams);

                Glide.with(this)
                        .load(baseImgUrl + collectionBean.getFilePath())
                        .into(binding.ivCollectionImg);
            }
        });

        viewModel.userBean.observe(this, userBean -> {
            if (userBean != null) {
                binding.etNickname.setText(userBean.getNickName());

              /*  if (!StringUtils.isEmpty(userBean.getAvatar())) {
                    Glide.with(this)
                            .load(baseImgUrl + userBean.getAvatar())
                            .into(binding.ivAvatar);
                }*/

            }

        });

        viewModel.hasUnReadMessage.observe(this, new Observer<Boolean>() {
            @Override
            public void onChanged(Boolean hasUnReadMessageFlag) {
                if (hasUnReadMessageFlag) {
                    binding.ivMessage.setImageDrawable(getContext().getDrawable(R.mipmap.wode_icon_xiaoxi2));
                } else {
                    binding.ivMessage.setImageDrawable(getContext().getDrawable(R.mipmap.wode_icon_xiaoxi1));
                }
            }
        });

        viewModel.nickNameEditFlag.observe(this, nickNameEditFlag -> {
            if (nickNameEditFlag) {
                binding.etNickname.setFocusable(true);
                binding.etNickname.setFocusableInTouchMode(true);
                binding.etNickname.setCursorVisible(true);
                binding.etNickname.requestFocus();
            } else {
                binding.etNickname.setFocusable(false);
                binding.etNickname.setFocusableInTouchMode(false);
            }
        });
    }


    @Override
    public MineViewModel initViewModel() {
        MineRequest lm = new MineRequest();
        return new MineViewModel(getActivity().getApplication(), lm);
    }
}