package com.xx.hbhconsumer.ui.mycollection;

import android.app.Application;
import android.os.Bundle;

import androidx.annotation.NonNull;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.CollectionRequest;
import com.xx.hbhconsumer.data.http.requst.PhoneRequest;
import com.xx.hbhconsumer.data.http.respons.CollectionBean;
import com.xx.hbhconsumer.data.http.respons.ShopBean;
import com.xx.hbhconsumer.data.http.respons.UserInfoBean;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.ui.goods.GoodsDetailActivity;
import com.xx.hbhconsumer.ui.login.LoginViewModel;
import com.xx.hbhconsumer.ui.main.MainActivity;
import com.xx.hbhconsumer.ui.phone.PhoneActivity;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.StringUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class MyCollectionViewModel extends BaseViewModel<CollectionRequest> {

    public MutableLiveData<List<CollectionBean>> collectionList = new  MutableLiveData<>(new ArrayList<>());
    public MutableLiveData<Boolean> editFlag = new  MutableLiveData<>(false);
    public MutableLiveData<Integer> checkCount = new  MutableLiveData<>(0);

    public MyCollectionViewModel(@NonNull Application application) {
        super(application);
    }

    public MyCollectionViewModel(@NonNull Application application, CollectionRequest model) {
        super(application, model);
    }

    @Override
    public void onCreate() {
        super.onCreate();
        loadData();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
    }

    public void goGoodsDetail(String goodsId) {
        Bundle bundle = new Bundle();
        bundle.putString("goodsId", goodsId);
        startActivity(GoodsDetailActivity.class, bundle);
    }

    private void loadData() {
        model.memberCollectionList()
                .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                .doOnSubscribe(MyCollectionViewModel.this)
                .doOnSubscribe (new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<CollectionBean>() {
                    @Override
                    public void onSuccess(List<CollectionBean> collectionBeanList) {
                        collectionList.postValue(collectionBeanList);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {

                    }


                });
    }


    public BindingCommand manager = new BindingCommand(new BindingAction() {
        @Override
        public void call() {

            if (collectionList.getValue().isEmpty()) {
                ToastUtils.showShort("无收藏可管理");
                return;
            }

            editFlag.postValue(true);
            List<CollectionBean> newList = new ArrayList<>();
            for (CollectionBean collectionBean : collectionList.getValue()) {
                collectionBean.setEditState(true);
                newList.add(collectionBean);
            }
            collectionList.postValue(newList);
        }

    });

    public BindingCommand confirm = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            editFlag.postValue(false);
            String businessIds = "";
            for (CollectionBean collectionBean : collectionList.getValue()) {
                if (collectionBean.getChecked()) {
                    businessIds += collectionBean.getBusinessId() + ",";
                }
            }
            if (StringUtils.isEmpty(businessIds)) {
                ToastUtils.showShort("请选择要取消收藏的商品");
                return;
            }

            model.cancelCollection(businessIds)
                    .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                    .doOnSubscribe(MyCollectionViewModel.this)
                    .doOnSubscribe (new Consumer<Disposable>() {
                        @Override
                        public void accept(Disposable disposable) throws Exception {
                        }
                    }).subscribe(new ApiDisposableObserver<Integer>() {
                        @Override
                        public void onSuccess(Integer resultBean) {
                            loadData();
                            editFlag.postValue(false);
                            checkCount.postValue(0);
                            ToastUtils.showShort("取消收藏成功");
                        }

                        @Override
                        public void onError(String Error) {
                            dismissDialog();
                        }

                    });

        }

    });

    public void checkItem() {
        int count = 0;
        for (CollectionBean collectionBean : collectionList.getValue()) {
            if (collectionBean.getChecked()) {
                count++;
            }
        }
        checkCount.postValue(count);
    }
}
