package com.xx.hbhconsumer.ui.mycoupon;

import android.app.Application;
import android.os.Bundle;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.CouponRequest;
import com.xx.hbhconsumer.data.http.respons.CouponGoodsBean;
import com.xx.hbhconsumer.data.http.respons.GoodsBean;
import com.xx.hbhconsumer.data.http.respons.SearchGoodsBean;
import com.xx.hbhconsumer.ui.goods.GoodsDetailActivity;
import com.xx.hbhconsumer.ui.search.SearchActivity;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class CouponGoodsListViewModel extends BaseViewModel<CouponRequest> {

    private String couponId;

    public MutableLiveData<Integer> sortType = new  MutableLiveData<>(0);
    public MutableLiveData<List<SearchGoodsBean>> searchGoodsBeanList = new  MutableLiveData<>(new ArrayList<>());
    public ObservableField<String> highPrice = new ObservableField<>("");
    public ObservableField<String> lowPrice = new ObservableField<>("");


    public MutableLiveData<Boolean> showSortFlag = new  MutableLiveData<>(false);
    public MutableLiveData<Boolean> showPriceFlag = new  MutableLiveData<>(false);

    Integer maxPrice = null;
    Integer minPrice = null;
    //时间顺序标识 0-时间降序,1-时间升序
    public String sortRules="0";
    public MutableLiveData<List<CouponGoodsBean>> goodsBeanList = new  MutableLiveData<>(new ArrayList<>());

    public CouponGoodsListViewModel(@NonNull Application application) {
        super(application);
    }

    public CouponGoodsListViewModel(@NonNull Application application, CouponRequest model, String couponId) {
        super(application, model);
        this.couponId = couponId;
    }

    public void goGoodsDetail(String goodsId) {
        Bundle bundle = new Bundle();
        bundle.putString("goodsId", goodsId);
        startActivity(GoodsDetailActivity.class, bundle);
    }

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        search();
    }

    private void search() {
        model.getCouponGoodsList(couponId, minPrice, maxPrice, null, sortRules)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(CouponGoodsListViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<CouponGoodsBean>() {
                    @Override
                    public void onSuccess(List<CouponGoodsBean> resultBean) {
                        goodsBeanList.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {

                    }


                });
    }


    public BindingCommand goSearch = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(SearchActivity.class);
        }

    });

    public BindingCommand finishActivity = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            finish();
        }

    });


    public BindingCommand search = new BindingCommand(() -> search());

    public BindingCommand reset = new BindingCommand(() -> {
        lowPrice.set("");
        highPrice.set("");
    });

    public BindingCommand searchPrice = new BindingCommand(() -> {
        try {
            maxPrice = Integer.parseInt(highPrice.get());
        } catch (Exception e) {
            ToastUtils.showShort("请输入正确最高价");
            return;
        }
        try {
            minPrice = Integer.parseInt(lowPrice.get());
        } catch (Exception e) {
            ToastUtils.showShort("请输入正确最低价");
            return;
        }
        if (minPrice >= maxPrice) {
            ToastUtils.showShort("最低价不能大于等于最高价");
            return;
        }
        search();
        showPriceFlag.postValue(!showPriceFlag.getValue());
    });

    public BindingCommand sortDefault = new BindingCommand(() -> {
        sortType.postValue(0);
        minPrice = null;
        maxPrice = null;
        sortRules = "0";
        search();
        showSortFlag.postValue(!showSortFlag.getValue());
    });

    public BindingCommand sortPriceDesc = new BindingCommand(() -> {
        sortType.setValue(1);
        minPrice = null;
        maxPrice = null;
        sortRules = "1";
        search();
        showSortFlag.postValue(!showSortFlag.getValue());
    });

    public BindingCommand sortPriceAsc = new BindingCommand(() -> {
        sortType.setValue(2);
        minPrice = null;
        maxPrice = null;
        sortRules = "2";
        search();
        showSortFlag.postValue(!showSortFlag.getValue());
    });


    public void sort(View view) {
        showSortFlag.postValue(!showSortFlag.getValue());
    }
    public void price(View view) {
        showPriceFlag.postValue(!showPriceFlag.getValue());
    }

}
