package com.xx.hbhconsumer.ui.order;

import android.app.Application;
import android.os.Bundle;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.OrderRequest;
import com.xx.hbhconsumer.data.http.respons.AvailableCoupon;
import com.xx.hbhconsumer.data.http.respons.AvailableCouponBean;
import com.xx.hbhconsumer.data.http.respons.ClaimedCoupon;
import com.xx.hbhconsumer.data.http.respons.CouponBean;
import com.xx.hbhconsumer.data.http.respons.OrderBean;
import com.xx.hbhconsumer.data.http.respons.UnavailableCoupon;
import com.xx.hbhconsumer.ui.credit.CreditsGoodsDetailActivity;
import com.xx.hbhconsumer.ui.main.MainActivity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class OrderDetailViewModel extends BaseViewModel<OrderRequest> {

    public MutableLiveData<Boolean> checkCouponFlag = new  MutableLiveData<>(false);
    public MutableLiveData<AvailableCoupon> coupon = new MutableLiveData<>(null);
    public MutableLiveData<OrderBean> orderBean = new  MutableLiveData<>(null);
    public MutableLiveData<ClaimedCoupon> claimedCoupon = new  MutableLiveData<>(null);

    private String orderId;
    private String couponDetailId = "";

    public OrderDetailViewModel(@NonNull Application application) {
        super(application);
    }

    public OrderDetailViewModel(@NonNull Application application, OrderRequest model, String orderId) {
        super(application, model);
        this.orderId = orderId;
    }


    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        loadGoodsData();
        loadCoupon();
    }

    public void loadGoodsData() {
        model.getOrderDetail(orderId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(OrderDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<OrderBean>() {
                    @Override
                    public void onSuccess(OrderBean resultBean) {
                        orderBean.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }


    public void loadCoupon() {
        model.getCouponAppList(orderId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(OrderDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<ClaimedCoupon>() {
                    @Override
                    public void onSuccess(ClaimedCoupon resultBean) {
                        List<AvailableCoupon> availableCouponList = new ArrayList<>();
                        List<UnavailableCoupon> unavailableCoupons = new ArrayList<>();
                        if (resultBean != null && resultBean.getAvailableCoupons() !=null) {
                            for (AvailableCoupon availableCoupon : resultBean.getAvailableCoupons()) {
                                if ("1".equals(availableCoupon.getCouponType())) {
                                    availableCouponList.add(availableCoupon);
                                }
                            }
                        }
                        if (resultBean != null && resultBean.getUnavailableCoupons() !=null) {
                            for (UnavailableCoupon unavailableCoupon : resultBean.getUnavailableCoupons()) {
                                if ("1".equals(unavailableCoupon.getCouponType())) {
                                    unavailableCoupons.add(unavailableCoupon);
                                }
                            }
                        }

                        ClaimedCoupon coupon = new ClaimedCoupon(availableCouponList, unavailableCoupons);

                        claimedCoupon.postValue(coupon);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

    public void cancel() {
        model.closeOrder(orderBean.getValue().getBusinessId())
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(OrderDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<Boolean>() {
                    @Override
                    public void onSuccess(Boolean resultBean) {
                        ToastUtils.showShort(" 关闭成功");
                        finish();
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

    public void chooseCoupon(View view) {
        if (claimedCoupon.getValue() == null || claimedCoupon.getValue().getAvailableCoupons() == null || claimedCoupon.getValue().getAvailableCoupons().size() == 0) {
            showNoCouponDialog(view);
        } else {
            showChooseCouponDialog(view, claimedCoupon.getValue());
        }
    }




    public BindingCommand cancel = new BindingCommand(() -> cancel());

    public void pay(View view) {
        if ("1".equals(orderBean.getValue().getInPay())) {
            showPayDialog(view);
        } else {
            submitOrder(view);
        }
    }

    public void submitOrder(View view) {

        model.submitOrder(orderId, couponDetailId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(OrderDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<Boolean>() {
                    @Override
                    public void onSuccess(Boolean resultBean) {
                        showPayDialog(view);
                    }
                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

    private void showPayDialog(View view) {
        BigDecimal actualPayment = BigDecimal.ZERO;
        if ("1".equals(orderBean.getValue().getInPay())) {
            String discountAmount = "0.00";
            if (orderBean.getValue().getCouponList() != null && !orderBean.getValue().getCouponList().isEmpty()) {
                for (CouponBean couponBean : orderBean.getValue().getCouponList()) {
                    if (couponBean.getCouponType().equals("1")) {
                        discountAmount = String.valueOf(couponBean.getDiscountAmount());
                    }
                }
            }
            actualPayment = new BigDecimal(String.valueOf(orderBean.getValue().getOrderAmount())).subtract(new BigDecimal(discountAmount));
        } else {
            if (coupon.getValue() == null) {
                actualPayment = new BigDecimal(String.valueOf(orderBean.getValue().getOrderAmount()));
            } else {
                actualPayment = new BigDecimal(String.valueOf(orderBean.getValue().getOrderAmount())).subtract(new BigDecimal(String.valueOf(coupon.getValue().getDiscountAmount())));
            }
        }

        OrderPayDialog dialog = new OrderPayDialog(view.getContext(), orderId, actualPayment.stripTrailingZeros().toPlainString());
        dialog.show();
    }

    private void showChooseCouponDialog(View view, ClaimedCoupon resultBean) {
        ChooseCouponDialog dialog = new ChooseCouponDialog(view.getContext(), resultBean, this);
        dialog.show();
    }

    public void confirmCoupon(AvailableCoupon availableCoupon) {
        checkCouponFlag.postValue(true);
        couponDetailId = availableCoupon.getBusinessId();
        coupon.postValue(availableCoupon);
    }

    private void showNoCouponDialog(View view) {
        NoCouponDialog dialog = new NoCouponDialog(view.getContext(), this);
        dialog.show();
    }

    public void goActivityCenter() {
        Bundle bundle = new Bundle();
        bundle.putInt("fragmentIndex", 2);
        startActivity(MainActivity.class, bundle);
        finish();
    }
}
