package com.xx.hbhconsumer.ui.order;

import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.scwang.smart.refresh.layout.api.RefreshLayout;
import com.scwang.smart.refresh.layout.listener.OnLoadMoreListener;
import com.scwang.smart.refresh.layout.listener.OnRefreshListener;
import com.xx.hbhconsumer.BR;
import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.adapter.OrderAdapter;
import com.xx.hbhconsumer.data.http.requst.OrderRequest;
import com.xx.hbhconsumer.databinding.FragmentOrderListBinding;

import me.goldze.mvvmhabit.base.BaseFragment;

public class OrderListFragment extends BaseFragment<FragmentOrderListBinding, OrderListViewModel> implements OnRefreshListener, OnLoadMoreListener {

    public static OrderListFragment newInstance(Integer orderStatus) {
        Bundle args = new Bundle();
        args.putInt("orderStatus", orderStatus);
        OrderListFragment fragment = new OrderListFragment();
        fragment.setArguments(args);
        return fragment;
    }

    @Override
    public void initData() {

        binding.refresh.setOnRefreshListener(this);
        binding.refresh.setOnLoadMoreListener(this);
        binding.refresh.setEnableFooterFollowWhenNoMoreData(true);
        //获取适配器上下文
        OrderAdapter orderListAdapter = new OrderAdapter(getActivity(), viewModel);

        //把adapterset进去
        binding.rvOrderList.setAdapter(orderListAdapter);
        orderListAdapter.setOnItemClick((position, data) -> viewModel.goOrderDetail(data.getBusinessId()));
        viewModel.orderList.observe(this, orderBeanList -> {
            if (orderBeanList.isEmpty()) {
                binding.rlNoData.setVisibility(View.VISIBLE);
                binding.rvOrderList.setVisibility(View.GONE);
                binding.refresh.setEnableLoadMore(false);
            } else {
                binding.rlNoData.setVisibility(View.GONE);
                binding.rvOrderList.setVisibility(View.VISIBLE);

                orderListAdapter.mList = orderBeanList;
                orderListAdapter.notifyDataSetChanged();

            }
            if (viewModel.page == 1) {
                binding.refresh.finishRefresh();
            } else {
                binding.refresh.finishLoadMore();
            }
            if (viewModel.page == viewModel.totalPage) {
                binding.refresh.setEnableLoadMore(false);
            } else {
                binding.refresh.setEnableLoadMore(true);
            }
        });

    }

    @Override
    public int viewModelType() {
        return 1;
    }

    @Override
    public int initContentView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        return R.layout.fragment_order_list;
    }

    @Override
    public int initVariableId() {
        return BR.orderListViewModel;
    }

    @Override
    public OrderListViewModel initViewModel() {
        OrderRequest model = new OrderRequest();
        Bundle args = getArguments();
        Integer orderStatus = args.getInt("orderStatus");
        String status = "";
        if (orderStatus > 0) {
            status = String.valueOf(orderStatus);
        }
        return new OrderListViewModel(getActivity().getApplication(), model, status);
    }

    @Override
    public void onLoadMore(@NonNull RefreshLayout refreshLayout) {
        viewModel.page++;

        if (viewModel.page > viewModel.totalPage) {
//            binding.refresh.setEnableLoadMore(false);
        } else if (viewModel.page == viewModel.totalPage) {
            binding.refresh.setEnableLoadMore(false);
            viewModel.loadData();
        } else {
            viewModel.loadData();
        }
    }

    @Override
    public void onRefresh(@NonNull RefreshLayout refreshLayout) {
        viewModel.page=1;
        viewModel.loadData();
        binding.refresh.setEnableLoadMore(true);
    }
}
