package com.xx.hbhconsumer.ui.order;

import android.app.Application;
import android.content.Context;
import android.os.Bundle;

import androidx.annotation.NonNull;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.OrderRequest;
import com.xx.hbhconsumer.data.http.respons.AvailableCouponBean;
import com.xx.hbhconsumer.data.http.respons.OrderBean;
import com.xx.hbhconsumer.ui.coupon.CouponListViewModel;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class OrderListViewModel extends BaseViewModel<OrderRequest> {
    public int page = 1;
    public int totalPage = 1;
    private String orderStatus;

    public MutableLiveData<List<OrderBean>> orderList = new  MutableLiveData<>(new ArrayList<>());

    public OrderListViewModel(@NonNull Application application, OrderRequest model, String orderStatus) {
        super(application, model);
        this.orderStatus = orderStatus;
    }
    public void goOrderDetail(String orderId) {
        Bundle bundle = new Bundle();
        bundle.putString("orderId", orderId);
        startActivity(OrderDetailActivity.class, bundle);
    }

    @Override
    public void onCreate() {
        super.onCreate();
        loadData();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
    }

    public void loadData() {
        model.getOrderList(orderStatus, page)
                .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                .doOnSubscribe(OrderListViewModel.this)
                .doOnSubscribe (new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<OrderBean>() {
                    @Override
                    public void onSuccess(List<OrderBean> orderBeanList) {
                        if (page == 1) {
                            orderList.postValue(orderBeanList);
                        } else {
                            List<OrderBean> list = orderList.getValue();
                            list.addAll(orderBeanList);
                            orderList.postValue(list);
                        }

                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {
                        totalPage = (total - 1) / 10 + 1;
                    }


                });
    }

    public void getAvailableCoupon(Context mContext, String couponType, String orderId) {
        model.getAvailableCoupons(couponType, orderId, null)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(OrderListViewModel.this)
                .doOnSubscribe ((Consumer<Disposable>) disposable -> {
                }).subscribe(new ApiDisposableObserver<List<AvailableCouponBean>>() {
                    @Override
                    public void onSuccess(List<AvailableCouponBean> orderBeanList) {
                        ReceiveCouponDialog dialog = new ReceiveCouponDialog(mContext, orderBeanList, OrderListViewModel.this);
                        dialog.show();
                    }
                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }
                });
    }
    public void getCoupon(String couponId) {
        model.getCoupon(couponId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(OrderListViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<Integer>() {
                    @Override
                    public void onSuccess(Integer resultBean) {
                        ToastUtils.showShort("领取成功");
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

}


