package com.xx.hbhconsumer.ui.park;

import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import androidx.lifecycle.Observer;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.xx.hbhconsumer.BR;
import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.data.http.requst.ParkRequest;
import com.xx.hbhconsumer.data.http.respons.ParkBean;
import com.xx.hbhconsumer.databinding.ActivityMessageCenterBinding;
import com.xx.hbhconsumer.dialog.CustomDialog;
import com.xx.hbhconsumer.dialog.adapter.ParkAdapter;
import com.xx.xxviewlibrary.comm.RefuseDialogBean;

import java.util.List;

import me.goldze.mvvmhabit.base.BaseActivity;

public class MyParkActivity extends BaseActivity<ActivityMessageCenterBinding, MyParkViewModel> {
    private MyParkViewModel myParkViewModel;
    private RecyclerView recyclerView;
    private ImageView zanwu_icon;
    private TextView zanwu_zi;
    private String deFlag = "0";
    /*适配器*/
    ParkAdapter parkAdapter;

    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_my_park_center;
    }

    @Override
    protected void onResume() {
        super.onResume();
        Log.v("deFlags是啥", deFlag);
        if (deFlag.equals("1")) {
            // 调用刷新数据的方法
            myParkViewModel.refreshData();
        }
    }

    @Override
    public void initData() {
        super.initData();
        // 初始化 RecyclerView
        recyclerView = findViewById(R.id.recycler_view);
        zanwu_icon = findViewById(R.id.zanwu_icon);
        zanwu_zi = findViewById(R.id.zanwu_zi);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));

        // 在 Activity/Fragment 中
        viewModel.parkAdapter = new ParkAdapter(this);
        //获取适配器上下文
        // 观察 parkBeanList 数据
        myParkViewModel.parkBeanList.observe(this, new Observer<List<ParkBean>>() {
            @Override
            public void onChanged(List<ParkBean> parkBeans) {
                if (parkBeans.size() > 0) {
                    deFlag = "1";
                    recyclerView.setAdapter(viewModel.parkAdapter);
                    zanwu_icon.setVisibility(View.GONE);
                    zanwu_zi.setVisibility(View.GONE);
                } else {
                    deFlag = "1";
                    zanwu_icon.setVisibility(View.VISIBLE);
                    zanwu_zi.setVisibility(View.VISIBLE);

                }
            }
        });
        // 设置长按事件的回调接口
        viewModel.parkAdapter.setOnItemLongClickListener(new ParkAdapter.OnItemLongClickListener() {
            @Override
            public void onItemLongClick(View view, int position, ParkBean parkBean) {
                // 去调删除接口
                showCustomDialog(new RefuseDialogBean("是否删除" + parkBean.getPlateNumber() + "该车牌号?", "确定", "取消"), new CustomDialog.onAcceptCallBack() {
                    @Override
                    public void acceptBack() {
                        myParkViewModel.deletePark(parkBean.getBusinessId());
                    }

                    @Override
                    public void refuseBack() {
                        // 取消操作不做任何处理
                    }
                });

            }
        });

    }
    // 新增方法：用于显示 CustomDialog
    private void showCustomDialog(RefuseDialogBean bean, CustomDialog.onAcceptCallBack callback) {
        CustomDialog customDialog = new CustomDialog(this, bean, callback);
        customDialog.show();
        // 获取弹窗的 Window 对象
        android.app.Dialog dialog = customDialog;
        if (dialog != null) {
            android.view.Window window = dialog.getWindow();
            if (window != null) {
                // 设置弹窗的 Gravity，例如居中
                window.setGravity(android.view.Gravity.CENTER);

                // 获取当前的 Window 参数
                android.view.WindowManager.LayoutParams layoutParams = window.getAttributes();

                // 调整弹窗的 Y 偏移量（向上抬）
                layoutParams.y = -85; // 这里的值可以根据需要调整，负值表示向上移动

                // 应用新的布局参数
                window.setAttributes(layoutParams);
            }
        }
    }
    @Override
    public int initVariableId() {
        return BR.myParkViewModel;
    }

    @Override
    public MyParkViewModel initViewModel() {
        ParkRequest parkRequest = new ParkRequest();
        myParkViewModel = new MyParkViewModel(getApplication(), parkRequest);
        return myParkViewModel;
    }

    public void goBack(View view) {
        finish();
    }



    @Override
    public void onPointerCaptureChanged(boolean hasCapture) {
        super.onPointerCaptureChanged(hasCapture);
    }
}