package com.xx.hbhconsumer.ui.park;

import android.content.Context;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.EditText;
import android.widget.Toast;

import com.google.android.material.tabs.TabLayout;
import com.google.android.material.tabs.TabLayout.OnTabSelectedListener;
import com.xx.hbhconsumer.BR;
import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.data.http.requst.ParkRequest;
import com.xx.hbhconsumer.data.http.respons.MyParkBean;
import com.xx.hbhconsumer.databinding.ActivityMyParkAddBinding;
import com.xx.hbhconsumer.dialog.MyParkDialog;
import com.xx.hbhconsumer.dialog.data.TextListProvider;
import com.xx.xxviewlibrary.base.xxBaseDialog;

import java.util.ArrayList;
import java.util.List;

import me.goldze.mvvmhabit.base.BaseActivity;

public class MyParkAddActivity extends BaseActivity<ActivityMyParkAddBinding, MyParkAddViewModel> {
    final String[] tabs = new String[]{"普通车牌号", "新能源车牌号"};
    TabLayout tabLayout;

    // 车辆类型（1：普通车辆，2：新能源）
    private String type = "1";
    private List<TextListProvider> deptList = new ArrayList<>();
    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_my_park_add;
    }

    @Override
    public int initVariableId() {
        return BR.myParkAddViewModel;
    }
    @Override
    public void initData() {
        super.initData();
        // 初始化 TabLayout
        tabLayout = findViewById(R.id.tabLayout);

        // 初始化新增车牌号输入框,设置样式
        EditText[] editTexts = new EditText[]{
                findViewById(R.id.editText1),
                findViewById(R.id.editText2),
                findViewById(R.id.editText3),
                findViewById(R.id.editText4),
                findViewById(R.id.editText5),
                findViewById(R.id.editText6),
                findViewById(R.id.editText7),
                findViewById(R.id.editText8)
        };

        // 设置输入框的焦点变化和文本变化监听器
        for (int i = 0; i < editTexts.length; i++) {
            final int index = i; // 当前输入框的索引
            EditText editText = editTexts[i];

            editText.setOnFocusChangeListener(new View.OnFocusChangeListener() {
                @Override
                public void onFocusChange(View v, boolean hasFocus) {
                    if (hasFocus) {
                        // 如果当前输入框获得焦点且内容为空，设置为“没有输入但点击了”的样式
                        if (editText.getText().toString().isEmpty()) {
                            editText.setBackground(getResources().getDrawable(R.drawable.edit_text_focused));
                        }
                        editText.setCursorVisible(true); // 显示光标
                    } else {
                        // 如果当前输入框失去焦点且内容为空，恢复默认样式
                        if (editText.getText().toString().isEmpty()) {
                            editText.setBackground(getResources().getDrawable(R.drawable.edit_text_default));
                        }
                        editText.setCursorVisible(false); // 隐藏光标
                    }
                }
            });

            editText.addTextChangedListener(new TextWatcher() {
                @Override
                public void beforeTextChanged(CharSequence s, int start, int count, int after) {
                }

                @Override
                public void onTextChanged(CharSequence s, int start, int before, int count) {
                }

                @Override
                public void afterTextChanged(Editable s) {
                    if (s.toString().length() == 1) {
                        // 如果当前输入框已满且不是最后一个输入框，则跳转到下一个输入框
                        if (index < editTexts.length - 1) {
                            editTexts[index + 1].requestFocus();
                        }
                    }
                    // 如果输入框内容被删除且当前输入框有焦点，设置为“没有输入但点击了”的样式
                    if (s.toString().isEmpty() && editText.isFocused()) {
                        editText.setBackground(getResources().getDrawable(R.drawable.edit_text_focused));
                    } else if (s.toString().isEmpty() && !editText.isFocused()) {
                        // 如果输入框内容为空且没有焦点，恢复默认样式
                        editText.setBackground(getResources().getDrawable(R.drawable.edit_text_default));
                    } else {
                        // 如果输入框有内容，设置为已填充样式
                        editText.setBackground(getResources().getDrawable(R.drawable.edit_text_filled));
                    }
                }
            });

            // 为每个输入框设置点击事件监听器
            editText.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    String[] licensePrefixes = {
                            "京", "津", "沪", "渝", "冀", "豫", "云", "辽", "黑", "湘",
                            "皖", "鲁", "新", "苏", "浙", "赣", "鄂", "桂", "琼","川", "陕",
                            "甘", "晋", "蒙", "吉", "闽", "贵", "粤", "青", "藏", "宁"
                    };
                    String[] licensePrefixesNumber = {
                            "A", "B", "C", "D", "E", "F", "G", "H", "J", "K", // 注意跳过了"I"
                            "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U",
                            "V", "W", "X", "Y", "Z", "0", "1", "2", "3", "4",
                            "5", "6", "7", "8", "9"
                    };

                    // 清空 deptList
                    deptList.clear();
                    if (index == 0) {
                        // 第一个输入框使用 licensePrefixes
                        for (int i = 0; i < licensePrefixes.length; i++) {
                            deptList.add(new MyParkBean(i + 1, licensePrefixes[i]));
                        }
                    } else {
                        // 其他输入框使用 licensePrefixesNumber
                        for (int i = 0; i < licensePrefixesNumber.length; i++) {
                            deptList.add(new MyParkBean(i + 1, licensePrefixesNumber[i]));
                        }
                    }


                    MyParkDialog dialog=new MyParkDialog(v.getContext(),deptList);
                    dialog.setDialogClickListener(new xxBaseDialog.onDialogClickListener<TextListProvider>() {
                        @Override
                        public void dialogClickBack(int code, TextListProvider data) {
                            // 获取标记的输入框
                            EditText targetEditText = (EditText) v.getTag();
                            if (targetEditText != null) {
                                targetEditText.setText(data.providerText()); // 将选择的内容赋值给对应的输入框
                            }
                        }
                    });

                    dialog.show();

                    // 设置当前点击的输入框标记
                    v.setTag(editText);
                    // 阻止输入框获取焦点
                    editText.clearFocus();

                    // 隐藏键盘
                    InputMethodManager imm = (InputMethodManager) getSystemService(Context.INPUT_METHOD_SERVICE);
                    if (imm != null) {
                        imm.hideSoftInputFromWindow(v.getWindowToken(), 0);
                    }
                }
            });
            // 设置输入框不可编辑
            editText.setFocusable(false);
            editText.setClickable(true);
        }

        // 添加 Tab
        for (String tab : tabs) {
            tabLayout.addTab(tabLayout.newTab().setText(tab));
        }

        // 设置 Tab 选中监听器
        tabLayout.addOnTabSelectedListener(new OnTabSelectedListener() {
            @Override
            public void onTabSelected(TabLayout.Tab tab) {
                // 车辆类型（1：普通车辆，2：新能源）
                if (tab.getText().equals("普通车牌号")) {
                    type = "1";
                    // 隐藏第八个输入框
                    editTexts[7].setVisibility(View.GONE);
                } else if (tab.getText().equals("新能源车牌号")) {
                    type = "2";
                    // 显示第八个输入框
                    editTexts[7].setVisibility(View.VISIBLE);
                }
            }

            @Override
            public void onTabUnselected(TabLayout.Tab tab) {
                // 当 Tab 未被选中时，不做处理
            }

            @Override
            public void onTabReselected(TabLayout.Tab tab) {
                // 当 Tab 被重新选中时，不做处理
            }
        });

        // 设置保存按钮的点击事件
        binding.saveButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                // 获取每个输入框的内容
                StringBuilder combinedString = new StringBuilder();
                for (EditText editText : editTexts) {
                    combinedString.append(editText.getText().toString());
                }

                // 将拼接后的字符串传递给 ViewModel
                viewModel.saveCombinedString(combinedString.toString(),type);
            }
        });
    }

    @Override
    public MyParkAddViewModel initViewModel() {
        ParkRequest parkRequest = new ParkRequest();
        return new MyParkAddViewModel(getApplication(), parkRequest);
    }
}