package com.xx.hbhconsumer.ui.park;

import android.app.Application;
import android.util.Log;
import android.widget.Toast;

import androidx.annotation.NonNull;

import com.xx.hbhconsumer.data.http.requst.ParkRequest;
import com.xx.hbhconsumer.data.http.respons.CollectionBean;

import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.http.BaseResponse;
import me.goldze.mvvmhabit.utils.RxUtils;

public class MyParkAddViewModel extends BaseViewModel<ParkRequest> {


    public MyParkAddViewModel(Application application, ParkRequest parkRequest) {
        super(application, parkRequest);
    }


    // 校验车牌号的方法
    private boolean isValidLicensePlate(String licensePlate) {
        // 定义车牌号的正则表达式
        // 以下正则表达式适用于常见的中国车牌号格式
        // 普通车牌：如“京A12345”
        // 新能源车牌：如“京A12345D”或“京AD12345”
        String regex = "^[京津沪渝冀豫云辽黑湘皖鲁新苏浙赣鄂桂甘晋蒙陕吉闽贵粤青藏川宁琼使领][A-HJ-NP-Z][A-HJ-NP-Z0-9]{4,5}[A-HJ-NP-Z0-9挂学警港澳]$";

        // 使用Pattern和Matcher进行校验
        return licensePlate.matches(regex);
    }

    // 添加一个方法来接收拼接后的字符串
    public void saveCombinedString(String combinedString, String type) {
        if (combinedString != null) {
            // 判断是否是新能源车牌号（假设新能源车牌以"D"或"F"结尾）
            String processedString = combinedString;
            if (type.equals("1") && !combinedString.isEmpty() && combinedString.length() == 7) {
                // 如果是普通车牌号，去掉最后一位
                processedString = combinedString.substring(0, combinedString.length() - 1);
                // 打印提示信息
//                Toast.makeText(getApplication().getApplicationContext(), "普通车牌号处理后：" + processedString, Toast.LENGTH_SHORT).show();
                // 校验combinedString是否是合格的车牌号
                if (!isValidLicensePlate(combinedString)) {
                    // 如果不是合格的车牌号，提示用户
                    Toast.makeText(getApplication().getApplicationContext(), "车牌号格式不正确", Toast.LENGTH_SHORT).show();
                    return; // 退出方法，不继续执行后续逻辑
                } else {
                    showDialog();

                    model.postParkMsg(combinedString, type)
                            .compose(RxUtils.schedulersTransformer()) //线程调度
                            .doOnSubscribe(MyParkAddViewModel.this)
                            .doOnSubscribe(new Consumer<Disposable>() {
                                @Override
                                public void accept(Disposable disposable) throws Exception {
                                }
                            }).subscribe(new ApiDisposableObserver<Boolean>() {
                                @Override
                                public void onSuccess(Boolean resultBean) {
                                    dismissDialog();
                                    // 在这里处理拼接后的字符串
                                    Toast.makeText(getApplication().getApplicationContext(), "添加车牌号成功", Toast.LENGTH_SHORT).show();
                                    finish();
                                }

                                @Override
                                public void onError(String Error) {
                                    dismissDialog();
                                }

                            });
                }
            } else if (type.equals("2") && !combinedString.isEmpty() && combinedString.length() == 8) {
                // 打印提示信息
//                Toast.makeText(getApplication().getApplicationContext(), "新能源车牌号处理后：" + processedString, Toast.LENGTH_SHORT).show();
                // 校验combinedString是否是合格的车牌号
                if (!isValidLicensePlate(combinedString)) {
                    // 如果不是合格的车牌号，提示用户
                    Toast.makeText(getApplication().getApplicationContext(), "车牌号格式不正确", Toast.LENGTH_SHORT).show();
                    return; // 退出方法，不继续执行后续逻辑
                } else {
                    showDialog();
                    model.postParkMsg(combinedString, type)
                            .compose(RxUtils.schedulersTransformer()) //线程调度
                            .doOnSubscribe(MyParkAddViewModel.this)
                            .doOnSubscribe(new Consumer<Disposable>() {
                                @Override
                                public void accept(Disposable disposable) throws Exception {
                                }
                            }).subscribe(new ApiDisposableObserver<Boolean>() {
                                @Override
                                public void onSuccess(Boolean resultBean) {
                                    dismissDialog();
                                    // 在这里处理拼接后的字符串
                                    Toast.makeText(getApplication().getApplicationContext(), "添加车牌号成功", Toast.LENGTH_SHORT).show();
                                    finish();
                                }

                                @Override
                                public void onError(String Error) {
                                    dismissDialog();
                                }

                            });
                }
            } else {

                // 打印提示信息
                Toast.makeText(getApplication().getApplicationContext(), "请输入完整车牌号", Toast.LENGTH_SHORT).show();

            }
        }

    }

}