package com.xx.hbhconsumer.ui.park;


import android.app.Application;
import android.util.Log;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.lifecycle.MutableLiveData;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.google.gson.Gson;
import com.xx.hbhconsumer.data.http.requst.ParkRequest;
import com.xx.hbhconsumer.data.http.respons.CollectionBean;
import com.xx.hbhconsumer.data.http.respons.ParkBean;
import com.xx.hbhconsumer.dialog.adapter.ParkAdapter;

import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.StringUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class MyParkViewModel extends BaseViewModel<ParkRequest> {
    /*适配器*/
    public  ParkAdapter parkAdapter;
    // 创建一个 MutableLiveData 来存储 ParkBean 数据列表
    public MutableLiveData<List<ParkBean>> parkBeanList = new MutableLiveData<>();

    public MyParkViewModel(Application application, ParkRequest parkRequest) {
        super(application, parkRequest);
    }

    @Override
    public void onCreate() {
        super.onCreate();
        loadData();
    }

    // 添加刷新数据的方法
    public void refreshData() {
        loadData(); // 调用加载数据的方法
    }
    private void loadData() {
        showDialog();
        model.getParkList()
                .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                .doOnSubscribe(MyParkViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<List<ParkBean>>() {

                    @Override
                    public void onSuccess(List<ParkBean> resultBean) {
                        dismissDialog();
                        parkAdapter.mList = resultBean;
                        parkBeanList.setValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

    public void deletePark(String businessId) {
        showDialog();
        model.deletePark(businessId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(MyParkViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<Boolean>() {
                    @Override
                    public void onSuccess(Boolean resultBean) {
                        ToastUtils.showShort("删除成功");
                        dismissDialog();
                        refreshData();
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }
                });
    }
    //返回按钮
    public BindingCommand goBack = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            finish();
        }
    });
    //跳转新增停车页面
    public BindingCommand goAddPark = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            Log.v("跳转新增停车页面", "");
            startActivity(MyParkAddActivity.class);
        }
    });
}


