package com.xx.hbhconsumer.ui.phone;

import static me.goldze.mvvmhabit.utils.Utils.Interceptor_TOKEN;

import android.app.Application;
import android.text.TextUtils;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;

import com.xx.hbhconsumer.data.http.requst.PhoneRequest;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.ui.login.LoginActivity;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class PhoneViewModel extends BaseViewModel<PhoneRequest> {

    //当前绑定手机号
    public ObservableField<String> currentPhone = new ObservableField<>("");
    //更换的手机号
    public ObservableField<String> changePhoneNumber = new ObservableField<>("");
    //验证码
    public ObservableField<String> code = new ObservableField<>("");

    public PhoneViewModel(@NonNull Application application) {
        super(application);
    }

    public PhoneViewModel(@NonNull Application application, PhoneRequest model) {
        super(application, model);
    }

    @Override
    public void onCreate() {
        super.onCreate();
        currentPhone.set(LocalData.getUser().getPhonenumber());
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
    }

    // 获取验证码
    public BindingCommand getCode = new BindingCommand(new BindingAction() {
        @Override
        public void call() {

            if (TextUtils.isEmpty(changePhoneNumber.get().toString())) {
                ToastUtils.showShort("请输入手机号！");
                return;
            }
            model.getCode(changePhoneNumber.get().toString())
                    .compose(RxUtils.schedulersTransformer()) //线程调度
                    .doOnSubscribe(PhoneViewModel.this)
                    .doOnSubscribe(new Consumer<Disposable>() {
                        @Override
                        public void accept(Disposable disposable) throws Exception {
                            showDialog("正在获取验证码");
                        }
                    }).subscribe(new ApiDisposableObserver<String>() {
                        @Override
                        public void onSuccess(String resultBean) {
//                            ToastUtils.showShort("已经发送成功");
                            ToastUtils.showShort(resultBean);
                            dismissDialog();
                        }
                        @Override
                        public void onError(String Error) {
                            dismissDialog();
                        }
                    });
        }
    });

    public BindingCommand changePhone = new BindingCommand(new BindingAction() {
        @Override
        public void call() {

            if (TextUtils.isEmpty(changePhoneNumber.get().toString())) {
                ToastUtils.showShort("请输入手机号！");
                return;
            }
            if (TextUtils.isEmpty(code.get().toString())) {
                ToastUtils.showShort("请输入验证码！");
                return;
            }
            model.changePhone(changePhoneNumber.get(), LocalData.getUser().getUserId(), code.get())
                    .compose(RxUtils.schedulersTransformer()) //线程调度
                    .doOnSubscribe(PhoneViewModel.this)
                    .doOnSubscribe(new Consumer<Disposable>() {
                        @Override
                        public void accept(Disposable disposable) throws Exception {

                        }
                    }).subscribe(new ApiDisposableObserver<String>() {
                        @Override
                        public void onSuccess(String resultBean) {
//                            //是指token
                            Interceptor_TOKEN = "Bearer " + resultBean;
                            startActivity(LoginActivity.class);
                        }
                        @Override
                        public void onError(String Error) {
                            dismissDialog();
                        }
                    });
        }
    });
}
