package com.xx.hbhconsumer.ui.recruit;

import android.Manifest;
import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.net.Uri;
import android.os.Bundle;
import android.util.Log;
import android.view.View;

import androidx.annotation.Nullable;
import androidx.core.app.ActivityCompat;

import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.data.http.requst.RecruitRequest;
import com.xx.hbhconsumer.databinding.ActivityRecruitDetailBinding;
import com.xx.hbhconsumer.utils.GetFilePathFromUri;

import java.io.File;

import me.goldze.mvvmhabit.base.BaseActivity;
import me.goldze.mvvmhabit.utils.ToastUtils;
import me.tatarka.bindingcollectionadapter2.BR;

public class RecruitDetailActivity extends BaseActivity<ActivityRecruitDetailBinding, RecruitDetailViewModel> {

    private static final String TAG = "RecruitDetailActivity";

    String[] mimeTypes =
            {"application/msword","application/vnd.openxmlformats-officedocument.wordprocessingml.document", // .doc & .docx
                    "application/pdf"};

    @Override
    public void initData() {
        super.initData();

        viewModel.recruitBean.observe(this, recruitBean -> {
            if (recruitBean != null) {
                binding.tvRecruitTitle.setText(recruitBean.getPostName());
                binding.tvRecruitCompany.setText("招聘企业：" + (recruitBean.getRecruitmentEnterprise() == null ? "环渤海" : recruitBean.getRecruitmentEnterprise()));

                // 1-内部招聘 2-商户招聘
                if ("1".equals(recruitBean.getRecruitmentType())) {
                    binding.btnChooseFile.setVisibility(View.VISIBLE);
                } else {
                    binding.btnChooseFile.setVisibility(View.GONE);
                }

                if (recruitBean.getWorkPlace().equals(2)) {
                    binding.tvAddress.setText("滨海宏达公司");
                } else {
                    binding.tvAddress.setText("环渤海河西");
                }

                binding.tvPostName.setText(recruitBean.getPostDescription());
                binding.tvContactInformation.setText(recruitBean.getContactInformationType());
                binding.tvProbationPeriod.setText(recruitBean.getOtherInformation());
                binding.tvPostDesc.setText(recruitBean.getPostResponsibility());
                binding.tvProbation.setText("试用期：" + recruitBean.getProbationPeriod() == null ? "无" : recruitBean.getProbationPeriod());

                if ("1".equals(recruitBean.getEducationalRequirement())) {
                    binding.tvEducation.setText("学历：硕士及以上");
                } else if ("2".equals(recruitBean.getEducationalRequirement())) {
                    binding.tvEducation.setText("学历：本科及以上");
                } else if ("3".equals(recruitBean.getEducationalRequirement())) {
                    binding.tvEducation.setText("学历：专科及以上");
                } else if ("4".equals(recruitBean.getEducationalRequirement())) {
                    binding.tvEducation.setText("学历：高中及以上");
                } else if ("5".equals(recruitBean.getEducationalRequirement())) {
                    binding.tvEducation.setText("学历：初中及以上");
                } else if ("6".equals(recruitBean.getEducationalRequirement())) {
                    binding.tvEducation.setText("学历：无");
                }


                if ("1".equals(recruitBean.getWorkExperience())) {
                    binding.tvExperience.setText("经验：1年");
                } else if ("2".equals(recruitBean.getWorkExperience())) {
                    binding.tvExperience.setText("经验：1-3年");
                } else if ("3".equals(recruitBean.getWorkExperience())) {
                    binding.tvExperience.setText("经验：3-5年");
                } else if ("4".equals(recruitBean.getWorkExperience())) {
                    binding.tvExperience.setText("经验：5-7年");
                } else if ("5".equals(recruitBean.getWorkExperience())) {
                    binding.tvExperience.setText("经验：7-10年");
                } else if ("6".equals(recruitBean.getWorkExperience())) {
                    binding.tvExperience.setText("经验：10年以上");
                } else if ("7".equals(recruitBean.getWorkExperience())) {
                    binding.tvExperience.setText("经验：无");
                }

                binding.tvSalary.setText(recruitBean.getPostWage());
            }

        });

        binding.btnChooseFile.setOnClickListener(view -> {
            int permission = ActivityCompat.checkSelfPermission(this,
                    Manifest.permission.READ_EXTERNAL_STORAGE);//缺少什么权限就写什么权限
            if (permission != PackageManager.PERMISSION_GRANTED) {
                // We don't have permission so prompt the user
                ToastUtils.showShort("申请的是文件读取权限，用于投递简历");
                ActivityCompat.requestPermissions(this, new String[]{Manifest.permission.READ_EXTERNAL_STORAGE,}, 0);
            }
            int permission2 = ActivityCompat.checkSelfPermission(this,
                    Manifest.permission.WRITE_EXTERNAL_STORAGE);//缺少什么权限就写什么权限
            if (permission2 != PackageManager.PERMISSION_GRANTED) {
                // We don't have permission so prompt the user
                ActivityCompat.requestPermissions(this, new String[]{Manifest.permission.WRITE_EXTERNAL_STORAGE,}, 0);
            }
            else{
                Intent intent = new Intent(Intent.ACTION_GET_CONTENT);
                //intent.setType("image/*");//选择图片
                //intent.setType("audio/*"); //选择音频
                //intent.setType("video/*"); //选择视频 （mp4 3gp 是android支持的视频格式）
                //intent.setType("video/*;image/*");//同时选择视频和图片
                intent.setType("*/*");//无类型限制
                intent.addCategory(Intent.CATEGORY_OPENABLE);
                startActivityForResult(intent, 1);
            }
        });
    }

    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_recruit_detail;
    }

    @Override
    public int initVariableId() {
        return BR.recruitDetailViewModel;
    }

    @Override
    public RecruitDetailViewModel initViewModel() {
        RecruitRequest model = new RecruitRequest();
        String id = getIntent().getStringExtra("id");
        return new RecruitDetailViewModel(getApplication(), model, id);
    }


    @SuppressLint("Range")
    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        String path;
        if (resultCode == Activity.RESULT_OK) {
            Uri uri = data.getData();//得到uri，后面就是将uri转化成file的过程。
            String filePath = GetFilePathFromUri.getFileAbsolutePath(this, uri);
            Log.i(TAG, "onActivityResult: " + filePath);
            if (!filePath.toLowerCase().endsWith(".pdf")) {
                ToastUtils.showShort("请选择正确的PDF文件");
                return;
            }
            viewModel.upLoadFile(new File(filePath));
        }
    }

}
