package com.xx.hbhconsumer.ui.register;

import static me.goldze.mvvmhabit.utils.Utils.Interceptor_TOKEN;

import android.app.Application;
import android.os.Bundle;
import android.text.TextUtils;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.LoginRequest;
import com.xx.hbhconsumer.data.http.requst.body.RegisterRequest;
import com.xx.hbhconsumer.data.http.respons.RegisterBean;
import com.xx.hbhconsumer.data.http.respons.UserInfoBean;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.ui.login.LoginActivity;
import com.xx.hbhconsumer.ui.main.MainActivity;
import com.xx.hbhconsumer.ui.privacyclause.PrivacyClauseActivity;
import com.xx.hbhconsumer.ui.pwd.ForgetPwdActivity;
import com.xx.hbhconsumer.ui.useragreement.UserAgreementActivity;
import com.xx.hbhconsumer.utils.PasswordUtil;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class RegisterViewModel extends BaseViewModel<RegisterRequest> {
    public MutableLiveData<Boolean> consentAgreementFlag = new  MutableLiveData<>(false);
    //用户名的绑定
    public ObservableField<String> phone = new ObservableField<>("");
    //密码的绑定
    public ObservableField<String> code = new ObservableField<>("");
    public ObservableField<String> password = new ObservableField<>("");
    public ObservableField<String> confirmPassword = new ObservableField<>("");

    public RegisterViewModel(@NonNull Application application, RegisterRequest model) {
        super(application, model);
    }

    public BindingCommand goPrivacyClause = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            Bundle bundle = new Bundle();
            bundle.putString("basic", "8");
            bundle.putString("basicName", "隐私条款");
            startActivity(UserAgreementActivity.class, bundle);
        }

    });

    public BindingCommand goUserAgreement = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            Bundle bundle = new Bundle();
            bundle.putString("basic", "5");
            bundle.putString("basicName", "用户协议");
            startActivity(UserAgreementActivity.class, bundle);
        }

    });

    //跳转忘记密码
    public BindingCommand goLogin = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(LoginActivity.class);
            finish();
        }

    });

    public BindingCommand getVerificationCode = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            if (TextUtils.isEmpty(phone.get().toString())) {
                ToastUtils.showShort("请输手机号码！");

            } else {
                model.checkRegisterPhone(phone.get())
                        .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                        .doOnSubscribe(RegisterViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
                                showDialog("正在请求...");
                            }
                        }).subscribe(new ApiDisposableObserver<Boolean>() {
                            @Override
                            public void onSuccess(Boolean resultBean) {
                                dismissDialog();
                                if (resultBean) {
                                    ToastUtils.showShort("该手机号已被注册，请返回登录");
                                } else {
                                    getCode();
                                }
                            }

                            @Override
                            public void onError(String Error) {
                                dismissDialog();
                            }

                        });
            }
        }
    });

    private void getCode() {
        model.getCode(phone.get())
                .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                .doOnSubscribe(RegisterViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                        showDialog("正在请求...");
                    }
                }).subscribe(new ApiDisposableObserver<String>() {
                    @Override
                    public void onSuccess(String resultBean) {
                        dismissDialog();
//                                ToastUtils.showShort("发送成功！");
                        ToastUtils.showShort(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

    public BindingCommand consentAgreement = new BindingCommand(() -> {
        if (consentAgreementFlag.getValue()) {
            consentAgreementFlag.postValue(false);
        } else {
            consentAgreementFlag.postValue(true);
        }

    });

    //登陆
    public BindingCommand register = new BindingCommand(() -> register());


    private void register() {
        if (TextUtils.isEmpty(phone.get().toString().replace(" ", ""))) {
            ToastUtils.showShort("请输入手机号码！");
        } else if (TextUtils.isEmpty(code.get().toString().replace(" ", ""))) {
            ToastUtils.showShort("请输入验证码！");
        } else if (TextUtils.isEmpty(password.get().toString().replace(" ", ""))) {
            ToastUtils.showShort("请输入密码！");
        } else if (TextUtils.isEmpty(confirmPassword.get().toString().replace(" ", ""))) {
            ToastUtils.showShort("请输入确认密码！");
        } else if (!confirmPassword.get().replace(" ", "").equals(password.get().replace(" ", ""))) {
            ToastUtils.showShort("密码与确认密码不一致！");
        } else if (password.get().replace(" ", "").length() < 8 || password.get().replace(" ", "").length() > 20) {
            ToastUtils.showShort("密码长度8-20位，需要同时包含大小写字母和数字");
        } else if (!PasswordUtil.isContainAll(password.get().replace(" ", ""))) {
            ToastUtils.showShort("密码长度8-20位，需要同时包含大小写字母和数字");
        } else if (!consentAgreementFlag.getValue()) {
            ToastUtils.showShort("请勾选同意协议");
        } else {
            model.register(phone.get().replace(" ", ""), password.get().replace(" ", ""), code.get().replace(" ", ""))
                    .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                    .doOnSubscribe(RegisterViewModel.this)
                    .doOnSubscribe(new Consumer<Disposable>() {
                        @Override
                        public void accept(Disposable disposable) throws Exception {
                            showDialog("正在请求...");
                        }
                    }).subscribe(new ApiDisposableObserver<RegisterBean>() {
                        @Override
                        public void onSuccess(RegisterBean resultBean) {
                            dismissDialog();
                            startActivity(LoginActivity.class);
                        }
                        @Override
                        public void onError(String Error) {
                            dismissDialog();
                        }

                    });
        }
    }

}


