package com.xx.hbhconsumer.ui.search;

import android.app.Application;
import android.os.Bundle;
import android.util.Log;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.SearchRequest;
import com.xx.hbhconsumer.data.http.respons.SearchGoodsBean;
import com.xx.hbhconsumer.data.http.respons.SearchShopBean;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.ui.credit.CreditsGoodsDetailActivity;
import com.xx.hbhconsumer.ui.goods.GoodsDetailActivity;
import com.xx.hbhconsumer.ui.shop.ShopDetailActivity;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.StringUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class SearchViewModel extends BaseViewModel<SearchRequest> {
    private static final String TAG = "SearchViewModel";
    public MutableLiveData<Integer> searchType = new  MutableLiveData<>(0);
    public MutableLiveData<Integer> sortType = new  MutableLiveData<>(0);
    public MutableLiveData<List<SearchGoodsBean>> searchGoodsBeanList = new  MutableLiveData<>(new ArrayList<>());
    public MutableLiveData<List<SearchShopBean>> searchShopBeanList = new  MutableLiveData<>(new ArrayList<>());
    public MutableLiveData<List<String>> searchWordList = new  MutableLiveData<>(new ArrayList<>());
    public ObservableField<String> searchWord = new ObservableField<>("");
    public ObservableField<String> highPrice = new ObservableField<>("");
    public ObservableField<String> lowPrice = new ObservableField<>("");


    public MutableLiveData<Boolean> showSortFlag = new  MutableLiveData<>(false);
    public MutableLiveData<Boolean> showPriceFlag = new  MutableLiveData<>(false);

    Integer maxPrice = null;
    Integer minPrice = null;
    String keyWord = "";
    public SearchViewModel(@NonNull Application application) {
        super(application);
    }

    public SearchViewModel(@NonNull Application application, SearchRequest model, String keyWord) {
        super(application, model);
        this.keyWord = keyWord;
    }

    @Override
    public void onCreate() {
        super.onCreate();

        if (!StringUtils.isEmpty(keyWord)) {
            searchWordClick(keyWord);
        } else {
            loadSearchHistory();
        }
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();

    }

    public void loadSearchHistory() {
        String searchWord = LocalData.getSearchWords();
        if (!StringUtils.isEmpty(searchWord)) {
            List<String> list = Arrays.asList(searchWord.split(","));
            List<String> tempList = new ArrayList<>();
            for (String item : list) {
                if (!StringUtils.isEmpty(item)) {
                    tempList.add(item);
                }
            }
            Collections.reverse(tempList);
            searchWordList.postValue(tempList);
        }
    }

    public void goGoodsDetail(String goodsId) {
        Bundle bundle = new Bundle();
        bundle.putString("goodsId", goodsId);
        startActivity(GoodsDetailActivity.class, bundle);
    }

    public void goShopDetail(String merchantId) {
        Bundle bundle = new Bundle();
        bundle.putString("merchantId", merchantId);
        startActivity(ShopDetailActivity.class, bundle);
    }

    public void search(Integer searchFlag) {

        if (searchFlag == 1) {
            searchType.postValue(1);
            searchGoods();
        } else if (searchFlag == 2) {
            searchType.postValue(2);
            searchShop();
        }
    }

    private void searchGoods() {

        model.searchGoods(searchWord.get(), minPrice, maxPrice, String.valueOf(sortType.getValue()), LocalData.getAffiliatedCompany())
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(SearchViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<SearchGoodsBean>() {
                    @Override
                    public void onSuccess(List<SearchGoodsBean> resultBean) {
                        searchGoodsBeanList.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {

                    }


                });
    }

    private void searchShop() {
        model.searchMerchant(searchWord.get(), LocalData.getAffiliatedCompany())
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(SearchViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<SearchShopBean>() {
                    @Override
                    public void onSuccess(List<SearchShopBean> resultBean) {
                        searchShopBeanList.postValue(resultBean);
                    }
                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }
                    @Override
                    public void getTotal(int total) {

                    }


                });
    }

    public BindingCommand search = new BindingCommand(() -> {

        if (StringUtils.isEmpty(searchWord.get())) {
            ToastUtils.showShort("请输入关键词");
            return;
        }
        LocalData.saveSearchWords(searchWord.get());
        if (searchType.getValue() == 0) {
            search(1);
        } else {
            search(searchType.getValue());
        }
    });

    public BindingCommand delSearchHistory = new BindingCommand(() -> {
        LocalData.saveSearchWords("");
        searchWordList.postValue(new ArrayList<>());
    });

    public BindingCommand reset = new BindingCommand(() -> {
        lowPrice.set("");
        highPrice.set("");
    });

    public BindingCommand searchPrice = new BindingCommand(() -> {
        try {
            maxPrice = Integer.parseInt(highPrice.get());
            minPrice = Integer.parseInt(lowPrice.get());
            if (minPrice >= maxPrice) {
                ToastUtils.showShort("最低价不能大于等于最高价");
                return;
            }
        } catch (Exception e) {
            maxPrice = null;
            minPrice = null;
        }

        search(1);
        showPriceFlag.postValue(!showPriceFlag.getValue());
    });

    public BindingCommand sortDefault = new BindingCommand(() -> {
        sortType.postValue(0);
        search(1);
        showSortFlag.postValue(!showSortFlag.getValue());
    });

    public BindingCommand sortPriceDesc = new BindingCommand(() -> {
        sortType.setValue(1);
        search(1);
        showSortFlag.postValue(!showSortFlag.getValue());
    });

    public BindingCommand sortPriceAsc = new BindingCommand(() -> {
        sortType.setValue(2);
        search(1);
        showSortFlag.postValue(!showSortFlag.getValue());
    });


    public void sort(View view) {
        Log.i(TAG, ": sort");
        showSortFlag.postValue(!showSortFlag.getValue());
    }
    public void price(View view) {
        Log.i(TAG, ": price");
        showPriceFlag.postValue(!showPriceFlag.getValue());
    }

    public void searchWordClick(String data) {
        searchWord.set(data);
        LocalData.saveSearchWords(searchWord.get());
        search(1);
    }
}
