package com.xx.hbhconsumer.ui.settings;

import android.app.Application;
import android.content.Context;
import android.content.SharedPreferences;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.util.Log;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;

import com.xx.hbhconsumer.data.http.requst.SettingsRequest;
import com.xx.hbhconsumer.data.http.respons.AppVersionBean;
import com.xx.hbhconsumer.data.http.respons.ShopDetailBean;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.ui.login.LoginActivity;
import com.xx.hbhconsumer.ui.logoff.LogoffFirstStepActivity;
import com.xx.hbhconsumer.ui.phone.PhoneActivity;
import com.xx.hbhconsumer.ui.pwd.PwdActivity;
import com.xx.hbhconsumer.ui.shop.ShopDetailViewModel;
import com.xx.hbhconsumer.ui.useragreement.UserAgreementActivity;
import com.xx.hbhconsumer.utils.VersionUpdateUtil;
import com.xx.xxviewlibrary.base.AppManager;
import com.xx.xxviewlibrary.base.xxBaseDialog;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class SettingsViewModel extends BaseViewModel<SettingsRequest> {

    public ObservableField<String> version = new ObservableField<>("");

    public SettingsViewModel(@NonNull Application application, SettingsRequest model) {
        super(application, model);
    }

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        getVersionName();
    }

    private void getVersionName() {
        //getPackageName()是你当前类的包名，0代表是获取版本信息
        PackageManager packageManager = getApplication().getPackageManager();
        PackageInfo packInfo = null;
        try {
            packInfo = packageManager.getPackageInfo(getApplication().getPackageName(), 0);
        } catch (PackageManager.NameNotFoundException e) {
            throw new RuntimeException(e);
        }
        version.set("当前版本V" + packInfo.versionName);
    }

    // none use
    public void goLogin() {
        LocalData.delAllData();
        SharedPreferences sharedPreferences = getApplication().getSharedPreferences("AppNamePreferences", Context.MODE_PRIVATE);

            // 获取SharedPreferences.Editor实例
            SharedPreferences.Editor editor = sharedPreferences.edit();
            // 清除username和password
            editor.remove("username");
            editor.remove("password");
            editor.remove("token");

            // 提交更改
            editor.apply();
            startActivity(LoginActivity.class); // 跳转到登录页面
            AppManager.getAppManager().finishAllActivityExThis(LoginActivity.class);
            finish();
//        startActivity(LoginActivity.class);
    }

    public BindingCommand goPrivacyClause = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            Bundle bundle = new Bundle();
            bundle.putString("basicName", "隐私条款");
            bundle.putString("basic", "8");
            startActivity(UserAgreementActivity.class, bundle);
        }

    });

    public BindingCommand checkUpdate = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            model.getVersion()
                    .compose(RxUtils.schedulersTransformer()) //线程调度
                    .doOnSubscribe(SettingsViewModel.this)
                    .doOnSubscribe(new Consumer<Disposable>() {
                        @Override
                        public void accept(Disposable disposable) throws Exception {
                        }
                    }).subscribe(new ApiDisposableObserver<AppVersionBean>() {
                        @Override
                        public void onSuccess(AppVersionBean resultBean) {
                            String versionStr = version.get().replace("当前版本V", "");
                            if (VersionUpdateUtil.compareVersion(versionStr, resultBean.getAppVersion()) < 0) {
                                ToastUtils.showShort("请到商店中更新");
                            } else {
                                ToastUtils.showShort("无更新");
                            }
                        }

                        @Override
                        public void onError(String Error) {
                            dismissDialog();
                        }
                    });
        }
    });


    //跳转开店页面
    public BindingCommand clearCache = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            ToastUtils.showShort("清除缓存成功");
        }
    });
    //跳转开店页面
    public BindingCommand goPhone = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(PhoneActivity.class);
        }
    });

    //跳转首页
    public BindingCommand goPwd = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(PwdActivity.class);
        }

    });

    //跳转忘记密码
    public BindingCommand logoff = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(LogoffFirstStepActivity.class);
        }

    });

    public void logout(View view) {
        showSignDialog(view);
    }

    private void showSignDialog(View view) {
        LogoutDialog dialog = new LogoutDialog(view.getContext(), this);
        dialog.setDialogClickListener((xxBaseDialog.onDialogClickListener<LogoutDialog>) (code, data) -> {

            Log.v("走去除去除","");
            // 获取SharedPreferences实例
            SharedPreferences sharedPreferences = getApplication().getSharedPreferences("AppNamePreferences", Context.MODE_PRIVATE);

            // 获取SharedPreferences.Editor实例
            SharedPreferences.Editor editor = sharedPreferences.edit();
            // 清除username和password
            editor.remove("username");
            editor.remove("password");
            editor.remove("token");

            // 提交更改
            editor.apply();
            startActivity(LoginActivity.class); // 跳转到登录页面
            finish();
//            startActivity(LoginActivity.class);
//            AppManager.getAppManager().finishAllActivityExThis(LoginActivity.class);
            LocalData.delAllData();
        });
        dialog.show();
    }

}


