package com.xx.hbhconsumer.ui.shop;

import android.os.Bundle;
import android.view.View;

import androidx.lifecycle.Observer;
import androidx.recyclerview.widget.GridLayoutManager;

import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.adapter.ShopDetailGoodsAdapter;
import com.xx.hbhconsumer.data.http.requst.ShopRequest;
import com.xx.hbhconsumer.data.http.respons.ShopDetailBean;
import com.xx.hbhconsumer.data.http.respons.ShopGoodsBean;
import com.xx.hbhconsumer.databinding.ActivityShopDetailBinding;

import java.util.List;

import me.goldze.mvvmhabit.base.BaseActivity;
import me.tatarka.bindingcollectionadapter2.BR;

public class ShopDetailActivity extends BaseActivity<ActivityShopDetailBinding, ShopDetailViewModel> {

    @Override
    public void initData() {
        super.initData();

        //获取适配器上下文
        GridLayoutManager manager = new GridLayoutManager(ShopDetailActivity.this,2);
        binding.rvGoodsList.setLayoutManager(manager);
        //获取适配器上下文
        ShopDetailGoodsAdapter orderListAdapter = new ShopDetailGoodsAdapter(ShopDetailActivity.this);
        //把adapterset进去
        binding.rvGoodsList.setAdapter(orderListAdapter);
        orderListAdapter.setOnItemClick((position, data) -> viewModel.goShopGoodsDetail(data.getBusinessId()));
        viewModel.shopGoodsBeanList.observe(this, new Observer<List<ShopGoodsBean>>() {
            @Override
            public void onChanged(List<ShopGoodsBean> shopBeanList) {

                orderListAdapter.mList = shopBeanList;
                orderListAdapter.notifyDataSetChanged();
                if (shopBeanList.isEmpty()) {
                    binding.rlNoData.setVisibility(View.VISIBLE);
                    binding.rvGoodsList.setVisibility(View.GONE);
                } else {
                    binding.rlNoData.setVisibility(View.GONE);
                    binding.rvGoodsList.setVisibility(View.VISIBLE);
                }
            }
        });

        viewModel.shopGoodsBean.observe(this, new Observer<ShopDetailBean>() {
            @Override
            public void onChanged(ShopDetailBean shopDetailBean) {
                if (shopDetailBean != null) {
                    binding.rbLevel.setRating(Float.parseFloat(String.valueOf(shopDetailBean.getRating())));
                    binding.tvShopName.setText(shopDetailBean.getStoreName());
                }

            }
        });

        viewModel.showSortFlag.observe(this, showSortFlag -> {
            if (showSortFlag) {
                binding.rlSearchArea.setVisibility(View.VISIBLE);
                binding.llSortSelect.setVisibility(View.VISIBLE);
                binding.rvGoodsList.setVisibility(View.GONE);
            } else {
                binding.llSortSelect.setVisibility(View.GONE);
                binding.rlSearchArea.setVisibility(View.GONE);
                binding.rvGoodsList.setVisibility(View.VISIBLE);
            }

        });

        viewModel.sortType.observe(this, sortType -> {
            if (sortType == 0) {
                binding.tvSortDefaultLabel.setTextColor(getColor(R.color.text_foreground));
                binding.ivSortDefault.setVisibility(View.VISIBLE);

                binding.tvSortPriceDescLabel.setTextColor(getColor(R.color.price_black));
                binding.ivSortPriceDesc.setVisibility(View.GONE);

                binding.tvSortPriceAscLabel.setTextColor(getColor(R.color.price_black));
                binding.ivSortPriceAsc.setVisibility(View.GONE);
            } else if (sortType == 1) {
                binding.tvSortDefaultLabel.setTextColor(getColor(R.color.price_black));
                binding.ivSortDefault.setVisibility(View.GONE);

                binding.tvSortPriceDescLabel.setTextColor(getColor(R.color.text_foreground));
                binding.ivSortPriceDesc.setVisibility(View.VISIBLE);

                binding.tvSortPriceAscLabel.setTextColor(getColor(R.color.price_black));
                binding.ivSortPriceAsc.setVisibility(View.GONE);
            } else {
                binding.tvSortDefaultLabel.setTextColor(getColor(R.color.price_black));
                binding.ivSortDefault.setVisibility(View.GONE);

                binding.tvSortPriceDescLabel.setTextColor(getColor(R.color.price_black));
                binding.ivSortPriceDesc.setVisibility(View.GONE);

                binding.tvSortPriceAscLabel.setTextColor(getColor(R.color.text_foreground));
                binding.ivSortPriceAsc.setVisibility(View.VISIBLE);
            }
        });
    }

    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_shop_detail;
    }

    @Override
    public int initVariableId() {
        return BR.shopDetailViewModel;
    }

    @Override
    public ShopDetailViewModel initViewModel() {
        ShopRequest lm = new ShopRequest();
        String merchantId = getIntent().getStringExtra("merchantId");
        return new ShopDetailViewModel(getApplication(), lm, merchantId);
    }
}
