package com.xx.hbhconsumer.ui.shop;

import android.app.Application;
import android.os.Bundle;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.ShopRequest;
import com.xx.hbhconsumer.data.http.respons.ShopDetailBean;
import com.xx.hbhconsumer.data.http.respons.ShopGoodsBean;
import com.xx.hbhconsumer.ui.category.CategoryActivity;
import com.xx.hbhconsumer.ui.goods.GoodsDetailActivity;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;

public class ShopDetailViewModel extends BaseViewModel<ShopRequest> {
    public String sortRules="0";
    public MutableLiveData<Integer> sortType = new  MutableLiveData<>(0);

    public MutableLiveData<Boolean> showSortFlag = new  MutableLiveData<>(false);

    public MutableLiveData<String> searchWord = new MutableLiveData<>("");
    public MutableLiveData<ShopDetailBean> shopGoodsBean = new MutableLiveData<>(null);
    private String merchantId;
    public MutableLiveData<List<String>> categoryIdList = new MutableLiveData<>(new ArrayList<>());
    public MutableLiveData<List<ShopGoodsBean>> shopGoodsBeanList = new  MutableLiveData<>(new ArrayList<>());

    public ShopDetailViewModel(@NonNull Application application, ShopRequest model, String merchantId) {
        super(application, model);
        this.merchantId = merchantId;
    }

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        loadShopDetail();
        loadShopGoodsList();
    }

    private void loadShopDetail() {
        model.getShopDetail(merchantId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(ShopDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<ShopDetailBean>() {
                    @Override
                    public void onSuccess(ShopDetailBean resultBean) {
                        shopGoodsBean.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }
                });
    }

    private void loadShopGoodsList() {
        model.getShopGoodsList(categoryIdList.getValue(), merchantId, searchWord.getValue(), sortRules)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(ShopDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<ShopGoodsBean>() {
                    @Override
                    public void onSuccess(List<ShopGoodsBean> resultBean) {
                        shopGoodsBeanList.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {

                    }

                });
    }

    public BindingCommand goCategory = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            Bundle bundle = new Bundle();
            bundle.putString("merchantId", merchantId);
            startActivity(CategoryActivity.class, bundle);
        }

    });

    public BindingCommand finishActivity = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            finish();
        }

    });

    public BindingCommand goShopSearch = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            Bundle bundle = new Bundle();
            bundle.putString("merchantId", merchantId);
            startActivity(ShopSearchActivity.class, bundle);
        }

    });

    public void goShopGoodsDetail(String goodsId) {
        Bundle bundle = new Bundle();
        bundle.putString("goodsId", goodsId);
        startActivity(GoodsDetailActivity.class, bundle);
    }

    public BindingCommand sortDefault = new BindingCommand(() -> {
        sortType.postValue(0);
        sortRules = "0";
        loadShopGoodsList();
        showSortFlag.postValue(!showSortFlag.getValue());
    });

    public BindingCommand sortPriceDesc = new BindingCommand(() -> {
        sortType.setValue(1);
        sortRules = "1";
        loadShopGoodsList();
        showSortFlag.postValue(!showSortFlag.getValue());
    });

    public BindingCommand sortPriceAsc = new BindingCommand(() -> {
        sortType.setValue(2);
        sortRules = "2";
        loadShopGoodsList();
        showSortFlag.postValue(!showSortFlag.getValue());
    });

    public void sort(View view) {
        showSortFlag.postValue(!showSortFlag.getValue());
    }
}


