package com.xx.hbhconsumer.ui.shop;

import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.Nullable;
import androidx.lifecycle.Observer;

import com.bumptech.glide.Glide;
import com.xx.hbhconsumer.BR;
import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.adapter.ShopAdapter;
import com.xx.hbhconsumer.adapter.ShopBannerAdapter;
import com.xx.hbhconsumer.data.http.requst.ShopRequest;
import com.xx.hbhconsumer.data.http.respons.ShopAndGoodsBean;
import com.xx.hbhconsumer.data.http.respons.ShopBean;
import com.xx.hbhconsumer.databinding.FragmentShopBinding;
import com.xx.hbhconsumer.utils.RetrofitClient;
import com.xx.xxviewlibrary.base.xxBaseRecyclerViewAdapter;
import com.youth.banner.indicator.CircleIndicator;
import com.youth.banner.listener.OnBannerListener;

import java.util.List;

import me.goldze.mvvmhabit.base.BaseFragment;

public class ShopFragment extends BaseFragment<FragmentShopBinding, ShopViewModel> {


    @Override
    public int viewModelType() {
        return 1;
    }

    @Override
    public int initContentView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        return R.layout.fragment_shop;
    }

    @Override
    public int initVariableId() {
        return BR.shopViewModel;
    }

    //    重写初始方法调用参数
    @Override
    public void initData() {
        super.initData();

        binding.banner.addBannerLifecycleObserver(this).setIndicator(new CircleIndicator(requireContext()));
        viewModel.shopBeanList.observe(this, shopBeanList -> {
            if (shopBeanList == null || shopBeanList.isEmpty()) {
                binding.banner.setVisibility(View.GONE);
                binding.tvBanner.setVisibility(View.GONE);
            } else {
                binding.banner.setVisibility(View.VISIBLE);
                binding.tvBanner.setVisibility(View.VISIBLE);
            }
            ShopBannerAdapter bannerAdapter=new ShopBannerAdapter(requireContext(), shopBeanList);
            binding.banner.setAdapter(bannerAdapter);
            bannerAdapter.setOnBannerListener(new OnBannerListener<ShopBean>() {
                @Override
                public void OnBannerClick(ShopBean data, int position) {
                    viewModel.goShopDetail(data.getStoreBusinessId());
                }
            });
        });

        viewModel.shopBean.observe(this, shopBean -> {

            if (shopBean == null) {
                binding.clTop.setVisibility(View.GONE);
            } else {
                binding.clTop.setVisibility(View.VISIBLE);
            }

            if (shopBean != null) {
                binding.tvShopName.setText(shopBean.getStoreName());
                binding.tvSlogan.setText(shopBean.getPropaganda());
                if (shopBean.getCoverImage() != null) {
                    Glide.with(getActivity())
                            .load(RetrofitClient.baseImgUrl + shopBean.getCoverImage())
                            .into(binding.ivTopShopImageBanner);
                }
            }
        });

        viewModel.shopAndGoodsBeanList.observe(this, shopAndGoodsBeanList -> {
            ShopAdapter orderListAdapter = new ShopAdapter(getActivity());
            //把adapterset进去
            binding.rvShop.setAdapter(orderListAdapter);
            orderListAdapter.mList = shopAndGoodsBeanList;
            orderListAdapter.setOnItemClick(new xxBaseRecyclerViewAdapter.OnItemClick<ShopAndGoodsBean>() {
                @Override
                public void itemClickCalBack(int position, ShopAndGoodsBean data) {
                    viewModel.goShopDetail(data.getStoreBusinessId());
                }
            });
        });

    }

    @Override
    public ShopViewModel initViewModel() {
        ShopRequest lm = new ShopRequest();
        return new ShopViewModel(getActivity().getApplication(), lm);
    }
}