package com.xx.hbhconsumer.ui.shop;

import android.os.Bundle;
import android.view.View;

import androidx.lifecycle.Observer;
import androidx.recyclerview.widget.GridLayoutManager;

import com.google.android.flexbox.FlexDirection;
import com.google.android.flexbox.FlexWrap;
import com.google.android.flexbox.FlexboxLayoutManager;
import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.adapter.SearchHistoryAdapter;
import com.xx.hbhconsumer.adapter.ShopDetailGoodsAdapter;
import com.xx.hbhconsumer.data.http.requst.ShopRequest;
import com.xx.hbhconsumer.data.http.respons.OrderBean;
import com.xx.hbhconsumer.data.http.respons.ShopGoodsBean;
import com.xx.hbhconsumer.databinding.ActivityShopSearchBinding;
import com.xx.xxviewlibrary.base.xxBaseRecyclerViewAdapter;

import java.util.ArrayList;
import java.util.List;

import me.goldze.mvvmhabit.base.BaseActivity;
import me.goldze.mvvmhabit.utils.StringUtils;
import me.tatarka.bindingcollectionadapter2.BR;

public class ShopSearchActivity extends BaseActivity<ActivityShopSearchBinding, ShopSearchViewModel> {

    private boolean firstLoad = true;

    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_shop_search;
    }

    @Override
    public int initVariableId() {
        return BR.shopSearchViewModel;
    }

    @Override
    public void initData() {
        super.initData();
        String merchantId = getIntent().getStringExtra("merchantId");
        if (StringUtils.isEmpty(merchantId)) {
            binding.tvSort.setVisibility(View.VISIBLE);
        } else {
            binding.tvSort.setVisibility(View.GONE);
        }
        viewModel.showSortFlag.observe(this, showSortFlag -> {
            if (showSortFlag) {
                binding.rlSearchArea.setVisibility(View.VISIBLE);
                binding.llSortSelect.setVisibility(View.VISIBLE);
                binding.rvGoodsList.setVisibility(View.GONE);
            } else {
                binding.llSortSelect.setVisibility(View.GONE);
                binding.rlSearchArea.setVisibility(View.GONE);
                binding.rvGoodsList.setVisibility(View.VISIBLE);
            }

        });

        viewModel.sortType.observe(this, sortType -> {
            if (sortType == 0) {
                binding.tvSortDefaultLabel.setTextColor(getColor(R.color.text_foreground));
                binding.ivSortDefault.setVisibility(View.VISIBLE);

                binding.tvSortPriceDescLabel.setTextColor(getColor(R.color.price_black));
                binding.ivSortPriceDesc.setVisibility(View.GONE);

                binding.tvSortPriceAscLabel.setTextColor(getColor(R.color.price_black));
                binding.ivSortPriceAsc.setVisibility(View.GONE);
            } else if (sortType == 1) {
                binding.tvSortDefaultLabel.setTextColor(getColor(R.color.price_black));
                binding.ivSortDefault.setVisibility(View.GONE);

                binding.tvSortPriceDescLabel.setTextColor(getColor(R.color.text_foreground));
                binding.ivSortPriceDesc.setVisibility(View.VISIBLE);

                binding.tvSortPriceAscLabel.setTextColor(getColor(R.color.price_black));
                binding.ivSortPriceAsc.setVisibility(View.GONE);
            } else {
                binding.tvSortDefaultLabel.setTextColor(getColor(R.color.price_black));
                binding.ivSortDefault.setVisibility(View.GONE);

                binding.tvSortPriceDescLabel.setTextColor(getColor(R.color.price_black));
                binding.ivSortPriceDesc.setVisibility(View.GONE);

                binding.tvSortPriceAscLabel.setTextColor(getColor(R.color.text_foreground));
                binding.ivSortPriceAsc.setVisibility(View.VISIBLE);
            }
        });

        FlexboxLayoutManager manager = new FlexboxLayoutManager(this, FlexDirection.ROW, FlexWrap.WRAP);
        binding.rvSearchHistory.setLayoutManager(manager);

        viewModel.searchState.observe(this, new Observer<Integer>() {
            @Override
            public void onChanged(Integer searchState) {
                if (searchState == 0) {
                    binding.rlCategoryBar.setVisibility(View.GONE);
                    binding.rvGoodsList.setVisibility(View.GONE);
                    binding.rlSearchHistoryBar.setVisibility(View.VISIBLE);
                    binding.rvSearchHistory.setVisibility(View.VISIBLE);
                } else {
                    binding.rlCategoryBar.setVisibility(View.VISIBLE);
                    binding.rvGoodsList.setVisibility(View.VISIBLE);
                    binding.rlSearchHistoryBar.setVisibility(View.GONE);
                    binding.rvSearchHistory.setVisibility(View.GONE);
                }
            }
        });

        //获取适配器上下文
        SearchHistoryAdapter searchHistoryAdapter = new SearchHistoryAdapter(this);
        //把adapterset进去
        binding.rvSearchHistory.setAdapter(searchHistoryAdapter);
        searchHistoryAdapter.setOnItemClick((position, data) -> {
            viewModel.searchWordClick(data);
            binding.etSearch.clearFocus();
        });

        viewModel.searchWordList.observe(this, searchWordList -> {
            searchHistoryAdapter.mList = searchWordList;
            searchHistoryAdapter.notifyDataSetChanged();
            if (searchWordList.isEmpty()) {
                binding.rlSearchHistoryBar.setVisibility(View.GONE);
                binding.rvSearchHistory.setVisibility(View.GONE);
            } else {
                binding.rlSearchHistoryBar.setVisibility(View.VISIBLE);
                binding.rvSearchHistory.setVisibility(View.VISIBLE);
            }
        });


        GridLayoutManager gridLayoutManager = new GridLayoutManager(ShopSearchActivity.this,2);
        binding.rvGoodsList.setLayoutManager(gridLayoutManager);
        //获取适配器上下文
        ShopDetailGoodsAdapter shopDetailGoodsAdapter = new ShopDetailGoodsAdapter(ShopSearchActivity.this);
        binding.rvGoodsList.setAdapter(shopDetailGoodsAdapter);
        shopDetailGoodsAdapter.setOnItemClick((position, data) -> viewModel.goShopGoodsDetail(data.getBusinessId()));
        viewModel.shopGoodsBeanList.observe(this, shopBeanList -> {
            if (shopBeanList == null) {
                return;
            }
            shopDetailGoodsAdapter.mList = shopBeanList;
            shopDetailGoodsAdapter.notifyDataSetChanged();
            if (shopBeanList.isEmpty()) {
                binding.rlNoData.setVisibility(View.VISIBLE);
                binding.rvGoodsList.setVisibility(View.GONE);
            } else {
                binding.rvGoodsList.setVisibility(View.VISIBLE);
                binding.rlNoData.setVisibility(View.GONE);
            }

            binding.rvSearchHistory.setVisibility(View.GONE);
            binding.rlSearchHistoryBar.setVisibility(View.GONE);
        });


        ShopDetailGoodsAdapter shopDetailGoodsAdapter1 = new ShopDetailGoodsAdapter(ShopSearchActivity.this);
        GridLayoutManager gridLayoutManager1 = new GridLayoutManager(ShopSearchActivity.this,2);
        binding.rvRecommend.setLayoutManager(gridLayoutManager1);
        binding.rvRecommend.setAdapter(shopDetailGoodsAdapter1);
        shopDetailGoodsAdapter1.setOnItemClick((position, data) -> viewModel.goShopGoodsDetail(data.getBusinessId()));

        viewModel.shopRecommendGoodsBeanList.observe(this, shopBeanList -> {
            if (shopBeanList == null) {
                return;
            }
            binding.rlCategoryBar.setVisibility(View.VISIBLE);
            shopDetailGoodsAdapter1.mList = shopBeanList;
            shopDetailGoodsAdapter1.notifyDataSetChanged();
        });

    }

    @Override
    public ShopSearchViewModel initViewModel() {
        ShopRequest lm = new ShopRequest();
        String categoryId = getIntent().getStringExtra("categoryId");
        String merchantId = getIntent().getStringExtra("merchantId");
        return new ShopSearchViewModel(getApplication(), lm, categoryId, merchantId);
    }
}
