package com.xx.hbhconsumer.ui.shop;

import android.app.Application;
import android.os.Bundle;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.ShopRequest;
import com.xx.hbhconsumer.data.http.respons.ShopGoodsBean;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.ui.category.CategoryActivity;
import com.xx.hbhconsumer.ui.goods.GoodsDetailActivity;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.StringUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class ShopSearchViewModel extends BaseViewModel<ShopRequest> {

    public String sortRules="0";
    public MutableLiveData<Integer> sortType = new  MutableLiveData<>(0);

    public MutableLiveData<Boolean> showSortFlag = new  MutableLiveData<>(false);

    private String categoryId;
    private String merchantId;
    private List<String> categoryIdList;
    public MutableLiveData<List<String>> searchWordList = new  MutableLiveData<>(new ArrayList<>());
    public MutableLiveData<List<ShopGoodsBean>> shopGoodsBeanList = new  MutableLiveData<>(null);
    public MutableLiveData<List<ShopGoodsBean>> shopRecommendGoodsBeanList = new  MutableLiveData<>(null);

    public MutableLiveData<Integer> searchState = new  MutableLiveData<>(0);

    public ObservableField<String> searchWord = new ObservableField<>("");

    public ShopSearchViewModel(@NonNull Application application) {
        super(application);
    }

    public ShopSearchViewModel(@NonNull Application application, ShopRequest model, String categoryId, String merchantId) {
        super(application, model);
        this.categoryId = categoryId;
        this.merchantId = merchantId;
        categoryIdList = new ArrayList<>();
        if (!StringUtils.isEmpty(categoryId)) {
            categoryIdList.add(categoryId);
        }
    }

    @Override
    public void onCreate() {
        super.onCreate();
        loadSearchHistory();
    }

    @Override
    public void onStart() {
        super.onStart();
        loadShopRecommendGoods();
    }

    @Override
    public void onResume() {
        super.onResume();
        if (!categoryIdList.isEmpty()) {
            search();
        }
    }
    private void loadSearchHistory() {
        String searchWord = LocalData.getSearchWords();
        if (!StringUtils.isEmpty(searchWord)) {
            List<String> list = Arrays.asList(searchWord.split(","));
            Collections.reverse(list);
            searchWordList.postValue(list);
        }
    }
    private void search() {
        model.getShopGoodsList(categoryIdList, merchantId, searchWord.get(), sortRules)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(ShopSearchViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<ShopGoodsBean>() {
                    @Override
                    public void onSuccess(List<ShopGoodsBean> resultBean) {
                        shopGoodsBeanList.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {
                    }

                });
    }

    public void loadShopRecommendGoods() {
        model.getSixCommodity(merchantId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(ShopSearchViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<List<ShopGoodsBean>>() {
                    @Override
                    public void onSuccess(List<ShopGoodsBean> resultBean) {
                        shopRecommendGoodsBeanList.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }
                });
    }

    public BindingCommand goCategory = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            Bundle bundle = new Bundle();
            bundle.putString("merchantId", merchantId);
            startActivity(CategoryActivity.class, bundle);
        }

    });

    public void goShopGoodsDetail(String goodsId) {
        Bundle bundle = new Bundle();
        bundle.putString("goodsId", goodsId);
        startActivity(GoodsDetailActivity.class, bundle);
    }


    public BindingCommand search = new BindingCommand(() -> {
        if (StringUtils.isEmpty(searchWord.get())) {
            ToastUtils.showShort("请输入关键词");
            return;
        }
        searchState.postValue(1);
        LocalData.saveSearchWords(searchWord.get());
        search();
    });


    public void searchWordClick(String data) {
        searchWord.set(data);
        search();
    }

    public BindingCommand sortDefault = new BindingCommand(() -> {
        sortType.postValue(0);
        sortRules = "0";
        search();
        showSortFlag.postValue(!showSortFlag.getValue());
    });

    public BindingCommand sortPriceDesc = new BindingCommand(() -> {
        sortType.setValue(1);
        sortRules = "1";
        search();
        showSortFlag.postValue(!showSortFlag.getValue());
    });

    public BindingCommand sortPriceAsc = new BindingCommand(() -> {
        sortType.setValue(2);
        sortRules = "2";
        search();
        showSortFlag.postValue(!showSortFlag.getValue());
    });

    public void sort(View view) {
        showSortFlag.postValue(!showSortFlag.getValue());
    }
}
